package rakete;
import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;

import org.opensourcephysics.display.Drawable;
import org.opensourcephysics.display.DrawingPanel;

/**
 * Klasse zum Zeichnen der beiden waagrechten Linien der Gesamtenergie 
 * der ein- und zweistufigen Rakete und der gestrichelten Nulllinie
 * @author Sarah Hipp
 */

public class MeineLinie implements Drawable {
	private double y;
	private double y1;
	private double xmax;
	// Das Objekt dashed besitzt die Eigenschaften f"ur die
	// gestrichelte Linie, wie z.B. Linienbreite,Linienabstand usw.
	private BasicStroke dashed = 
			new BasicStroke(2.0f, BasicStroke.CAP_BUTT,
			BasicStroke.JOIN_MITER, 10.0f, new float[] { 10.0f }, 0.0f);

	// y-Wert der Linie der zweistufigen Rakete
	public void setY(double y) {
		this.y = y;
	}

	// y-Wert der Linie der einstufigen Rakete
	public void setY1(double y1) {
		this.y1 = y1;
	}

	// x-Wert des Endpunktes der Linien
	public void setXmax(double xmax) {
		this.xmax = xmax;
	}

	public MeineLinie(double y, double y1, double xmax) {
		this.y = y;
		this.y1 = y1;
		this.xmax = xmax;
	}

	@Override
	public void draw(DrawingPanel panel, Graphics g) {
		// Das Graphics-Element wird in ein Graphics2D-Element verwandelt,
		// damit die gestrichelte Nulllinie gezeichnet werden kann.
		Graphics2D g2 = (Graphics2D) g;
		g2.setColor(Color.black);
		g2.drawLine(0, panel.yToPix(y), panel.xToPix(xmax), panel.yToPix(y));
		g2.setColor(Color.red);
		g2.drawLine(0, panel.yToPix(y1), panel.xToPix(xmax), panel.yToPix(y1));
		g2.setColor(Color.black);
		g2.setStroke(dashed);
		g2.drawLine(0, panel.yToPix(0), panel.xToPix(xmax), panel.yToPix(0));
	}
}

/*
 * This software is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General 
 * Public License (GPL) as published by the Free Software 
 * Foundation; either version 3 of the License, 
 * or(at your option) any later version.
 *
 * This software is distributed in the hope that it will 
 * be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE.  
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General 
 * Public License along with this; 
 * if not, see <http://www.gnu.org.licenses>
 */