package rakete;
/**
 * Klasse zur Erzeugung eines Unterfensters, 
 * welches Informationen zum Programm beinhaltet.
 * @author Sarah Hipp
 */

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.Toolkit;

import javax.swing.BoxLayout;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

import org.opensourcephysics.display.Dataset;
import org.opensourcephysics.display.PlottingPanel;

public class ParameterFenster extends JDialog {
	public ParameterFenster(JFrame owner) {
		super(owner, "Informationen zum Programm", false);
		
		//Objekt der Klasse MeinRechteck anlegen
		MeinRechteck rechteck;
		
		//Dataset vordefinieren
		Dataset gravPotData;
		
		// Werte f"ur das Gravitationspotential der Erde vordefinieren
		double xAnzahl = 10000; //Anzahl der Werte
		double xmax = 5E8; //maximaler x-Wert
		double x = 0;
		double f = 0;
		
		
		// Einzelne Schriftgr"ossen, Hintergrundfarbe und 
		// Dimension des Panels festlegen
		Font uebFont = new Font("Arial Unicode MS", Font.BOLD, 14);
		Font textFont = new Font("Arial Unicode MS", Font.PLAIN, 14);
		Color colorbg = new Color(222, 222, 222);
		Dimension dim= new Dimension(400,200);
		
		// Unterfenster in der Mitte des Hauptfensters positionieren, 
		// Gr"osse und Layout festlegen
		Dimension screen = Toolkit.getDefaultToolkit().getScreenSize();
		setBounds((screen.width - 1000) / 2, 
				(screen.height - 700) / 2, 1000, 700);
		setSize(new Dimension(1000, 700));
		JPanel fensterPane = new JPanel();
		GridBagLayout fensterLayout = new GridBagLayout();
		fensterPane.setLayout(fensterLayout);
		fensterPane.setBackground(colorbg);
		
		// Label f"ur die "Uberschrift der DGL erstellen
		JLabel dglUebLabel = new JLabel("Verwendete DGL:");
		dglUebLabel.setFont(uebFont);
		
		// Label f"ur die DGL erstellen
		JLabel dglLabel = new JLabel(
				"z\u0308 = -G\u22C5M /(x+R)\u00B2 + \u03B1\u22C5v/m");
		dglLabel.setFont(textFont);

		// Label f"ur die Masse1
		JLabel masse1Label = new JLabel(
				"mit    m=m\u2080 + m\u2081 + mt\u2081 (einstufige Rakete)");
		masse1Label.setFont(textFont);
		
		// Label f"ur die Masse2
		JLabel masse2Label = new JLabel(
				"bzw. m=m\u2080 + m\u2082\u2081 + mt\u2082\u2081 + m\u2082\u2082 "
				+ "+ mt\u2082\u2082 (zweistufige Rakete)");
		masse2Label.setFont(textFont);

		// Panel f"ur die DGL erstellen und Label untereinander hinzuf"ugen
		JPanel dglPanel = new JPanel();
		dglPanel.setLayout(new BoxLayout(dglPanel, BoxLayout.Y_AXIS));
		dglPanel.add(dglUebLabel);
		dglPanel.add(dglLabel);
		dglPanel.add(masse1Label);
		dglPanel.add(masse2Label);
		dglPanel.setBackground(colorbg);

		// Label für das Verfahren erstellen
		// "Uberschrift
		JLabel RKLabel = new JLabel("Verwendetes numerisches Verfahren:");
		RKLabel.setFont(uebFont);

		// RK-Verfahren
		JLabel rkLabel = new JLabel("Runge-Kutta-Verfahren der Stufe 4");
		rkLabel.setFont(textFont);

		// Panel für das Verfahren erstellen und Label hinzuf"ugen
		JPanel RKPanel = new JPanel();
		RKPanel.setLayout(new BoxLayout(RKPanel, BoxLayout.Y_AXIS));
		RKPanel.add(RKLabel);
		RKPanel.add(rkLabel);
		RKPanel.setBackground(colorbg);

		// Label für die verwendeten Konstanten erstellen
		// "Uberschrift
		JLabel konLabel = new JLabel("Verwendete Konstanten:");
		konLabel.setFont(uebFont);

		// Gravitationskonstante
		JLabel gravLabel = new JLabel(
				"Gravitationskonstante: G = 6,67 \u22C5 "
				+ "10\u207B\u00B9\u00B9 kg\u00B3/(m\u22C5s\u00B2)");
		gravLabel.setFont(textFont);

		// Erdmasse
		JLabel erdmLabel = new JLabel(
				"Erdmasse: M = 5,98 \u22C5 10\u00B2\u2074 kg");
		erdmLabel.setFont(textFont);

		// Erdradius
		JLabel erdrLabel = new JLabel(
				"Erdradius: R = 6,37 \u22C5 10\u2076 m");
		erdrLabel.setFont(textFont);

		// Panel f"ur die verwendeten Konstanten erstellen 
		// und Label hinzuf"ugen
		JPanel konPanel = new JPanel();
		konPanel.setLayout(new BoxLayout(konPanel, BoxLayout.Y_AXIS));
		konPanel.add(konLabel);
		konPanel.add(gravLabel);
		konPanel.add(erdmLabel);
		konPanel.add(erdrLabel);
		konPanel.setBackground(colorbg);

		// Label f"ur die verwendeten Parameter erstellen
		// "Uberschrift
		JLabel uebLabel = new JLabel("Verwendete Parameter:");
		uebLabel.setFont(uebFont);

		// pro Zeiteinheit ausgestossene Gasmasse
		JLabel alphaLabel = new JLabel(
				"pro Zeiteinheit ausgesto\u00DFene Gasmasse: "
				+ "\u03B1  = 13,84 \u22C5 10\u00B3 kg/s");
		alphaLabel.setFont(textFont);

		// Masse der einstufigen Rakete 
		JLabel einstufigLabel = new JLabel(
				"Masse der einstufigen Rakete:");
		einstufigLabel.setFont(textFont);
		
		// Raketenkopfmasse
		JLabel kopfmLabel = new JLabel(
				"     Raketenkopfmasse: m\u2080 = 1 \u22C5 10\u2076 kg");
		kopfmLabel.setFont(textFont);

		// Tankh"ullenmasse
		JLabel tank1Label = new JLabel(
				"     Tankh\u00fcllenmasse + Triebwerkmasse: "
				+ "m\u2081 = (0,8 bis 4,8) \u22C5 10\u2074 kg");
		tank1Label.setFont(textFont);

		// Treibstoffmasse
		JLabel tankMasse1Label = new JLabel(
				"     Treibstoffmasse: mt\u2081= "
				+ "(0,5 bis 3,0) \u22C5 10\u2075 kg");
		tankMasse1Label.setFont(textFont);
		
		//Masse der zweistufigen Rakete
		JLabel zweistufigLabel = new JLabel("Masse der zweistufigen Rakete:");
		zweistufigLabel.setFont(textFont);
		
		// Raketenkopfmasse
				JLabel kopfmLabel1 = new JLabel(
						"     Raketenkopfmasse: m\u2080 = 1 \u22C5 10\u2076 kg");
				kopfmLabel1.setFont(textFont);
		
		// erste Tankh"ullenmasse
		JLabel tank2aLabel = new JLabel(
				"     erste Tankh\u00fcllenmasse + Triebwerkmasse: "
				+ "m\u2082\u2081 = (0,8 bis 4,0) \u22C5 10\u2074 kg");
		tank2aLabel.setFont(textFont);
		
		// zweite Tankh"ullenmasse
		JLabel tank2bLabel = new JLabel(
				"     zweite Tankh\u00fcllenmasse + Triebwerkmasse: "
				+ "m\u2082\u2082 = (0,8 bis 4,0) \u22C5 10\u2074 kg");
		tank2bLabel.setFont(textFont);
		
		// Treibstoffmasse erster Tank
		JLabel tankMasse2aLabel = new JLabel(
				"     Treibstoffmasse erster Tank: "
				+ "mt\u2082\u2081= (0,5 bis 2,5) \u22C5 10\u2075 kg");
		tankMasse2aLabel.setFont(textFont);
		
		// Treibstoffmasse zweiter Tank
		JLabel tankMasse2bLabel = new JLabel(
				"     Treibstoffmasse zweiter Tank: "
				+ "mt\u2082\u2082= (0,5 bis 2,5) \u22C5 10\u2075 kg");
		tankMasse2bLabel.setFont(textFont);

		// Ausstossgeschwindigkeit
		JLabel geschwLabel = new JLabel(
				"Aussto\u00DFgeschwindigkeit: "
				+ "v = 2,46 \u22C5 10\u00B3 m/s");
		geschwLabel.setFont(textFont);

		// Ausstossgeschwindigkeit Turbo
		JLabel geschwTurboLabel = new JLabel(
				"Turbo-Aussto\u00DFgeschwindigkeit: "
				+ "v\u0304 = 3,1 \u22C5 10\u2074 m/s");
		geschwTurboLabel.setFont(textFont);

		// Panel f"ur die verwendeten Parameter erstellen 
		// und Label hinzuf"ugen
		JPanel parPanel = new JPanel();
		parPanel.setLayout(new BoxLayout(parPanel, BoxLayout.Y_AXIS));
		parPanel.add(uebLabel);
		parPanel.add(alphaLabel);
		parPanel.add(einstufigLabel);
		parPanel.add(kopfmLabel);
		parPanel.add(tank1Label);
		parPanel.add(tankMasse1Label);
		parPanel.add(zweistufigLabel);
		parPanel.add(kopfmLabel1);
		parPanel.add(tank2aLabel);
		parPanel.add(tank2bLabel);
		parPanel.add(tankMasse2aLabel);
		parPanel.add(tankMasse2bLabel);
		parPanel.add(geschwLabel);
		parPanel.add(geschwTurboLabel);
		parPanel.setBackground(colorbg);
		

		//vordefiniertes Dataset des Gravitationspotentials anlegen
		gravPotData = new Dataset();
		gravPotData.setMarkerShape(Dataset.NO_MARKER);
		gravPotData.setConnected(true);
		gravPotData.setLineColor(Color.blue);
		
		//Gravitationspotential berechnen
		for (int i = 0; i <= xAnzahl; i++) {
		x = -6.371E6+i * xmax / xAnzahl;
		f = -6.67408E-11 * 5.9722E24/(x+6.371E6);
		//dem Dataset Daten hinzuf"ugen
		gravPotData.append(x, f);}

		// Panel für das Gravitationspotential vorbelegen
		PlottingPanel gravPlot = new PlottingPanel("H\u00f6he in m",
		"Energie in J/kg","Gravitationspotential der Erde:");
		gravPlot.setYMarginPercentage(10);
		gravPlot.setPreferredMinMaxX(0, 5E7);
		gravPlot.setPreferredMinMaxY(-6.5E7, 0);
		gravPlot.setPreferredSize(dim);
		gravPlot.setFont(textFont);
		gravPlot.setAntialiasTextOn(true);
		gravPlot.enableInspector(false);
		gravPlot.addDrawable(gravPotData);
   
		//Rechteck erzeugen und positionieren 
		rechteck= new MeinRechteck(0,-5.15E7,2E6,-6.45E7);
		gravPlot.addDrawable(rechteck);
		gravPlot.repaint();
		gravPlot.setBackground(colorbg);
		gravPlot.setOpaque(false);

		// Label für die Energie
		JLabel energieLabel = new JLabel(
				"<html>Die Gesamtenergie der Raketen wurde als "
				+ "Summe aus kinetischer<br>"
				+"<html>und potentieller Energie berechnet. "
				+ "Sowohl die potentielle Energie<br>"
				+"<html>als auch die Gesamtenergie wurden "
				+ "auf die Masse normiert. <br>"
				+"<html>Ohne Turbo-Aussto\u00DFgeschwindigkeit "
				+ "wird das Graviatations-<br>"
				+"<html>potential der Erde nur im Bereich "
				+ "des roten Rechtecks betrachtet,<br>"
				+"<html>daher erscheint das Potential "
				+ "im Energie-Plot nahezu linear.");
		energieLabel.setFont(textFont);

		// Panel für das Gravitationspotential
		JPanel gravErdePanel = new JPanel();
		gravErdePanel.setLayout(new BoxLayout(gravErdePanel, BoxLayout.Y_AXIS));
		gravErdePanel.add(gravPlot);
		gravErdePanel.setBackground(colorbg);

		// Elemente im Fenster anordnen
		GridBagConstraints gbDGL = new GridBagConstraints();
		gbDGL.gridx = 0;
		gbDGL.gridy = 0;
		gbDGL.gridwidth = 1;
		gbDGL.gridheight = 1;
		gbDGL.anchor = GridBagConstraints.NORTHWEST;
		gbDGL.insets = new Insets(5, 0, 20, 0);
		fensterLayout.setConstraints(dglPanel, gbDGL);
		fensterPane.add(dglPanel);

		GridBagConstraints gbVerfahren = new GridBagConstraints();
		gbVerfahren.gridx = 0;
		gbVerfahren.gridy = 1;
		gbVerfahren.gridwidth = 1;
		gbVerfahren.gridheight = 1;
		gbVerfahren.anchor = GridBagConstraints.NORTHWEST;
		gbVerfahren.insets = new Insets(0, 0, 20, 0);
		fensterLayout.setConstraints(RKPanel, gbVerfahren);
		fensterPane.add(RKPanel);

		GridBagConstraints gbKonstanten = new GridBagConstraints();
		gbKonstanten.gridx = 0;
		gbKonstanten.gridy = 2;
		gbKonstanten.gridwidth = 1;
		gbKonstanten.gridheight = 1;
		gbKonstanten.anchor = GridBagConstraints.NORTHWEST;
		gbKonstanten.insets = new Insets(0, 0, 20, 0);
		fensterLayout.setConstraints(konPanel, gbKonstanten);
		fensterPane.add(konPanel);

		GridBagConstraints gbParameter = new GridBagConstraints();
		gbParameter.gridx = 0;
		gbParameter.gridy = 3;
		gbParameter.gridwidth = 1;
		gbParameter.gridheight = 1;
		gbParameter.anchor = GridBagConstraints.NORTHWEST;
		fensterLayout.setConstraints(parPanel, gbParameter);
		fensterPane.add(parPanel);

		GridBagConstraints gbgravPot = new GridBagConstraints();
		gbgravPot.gridx = 1;
		gbgravPot.gridy = 0;
		gbgravPot.gridwidth = 1;
		gbgravPot.gridheight = 3;
		gbgravPot.anchor = GridBagConstraints.WEST;
		gbgravPot.insets = new Insets(20, 40, 20, 0);
		fensterLayout.setConstraints(gravErdePanel, gbgravPot);
		fensterPane.add(gravErdePanel);
		
		GridBagConstraints gbText = new GridBagConstraints();
		gbText.gridx = 1;
		gbText.gridy = 3;
		gbText.gridwidth = 1;
		gbText.gridheight = 1;
		gbText.anchor = GridBagConstraints.NORTHWEST;
		gbText.insets = new Insets(-5, 40, 0, 0);
		fensterLayout.setConstraints(energieLabel, gbText);
		fensterPane.add(energieLabel);
		
		add(fensterPane);

	}
}

/*
 * This software is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General 
 * Public License (GPL) as published by the Free Software 
 * Foundation; either version 3 of the License, 
 * or(at your option) any later version.
 *
 * This software is distributed in the hope that it will 
 * be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE.  
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General 
 * Public License along with this; 
 * if not, see <http://www.gnu.org.licenses>
 */
