package rakete;

/**
 * DGL für die einstufige Rakete
 * @author Sarah Hipp
 */

class RaketeDgl1 extends RK_NumDgl {
	private double G = 6.67E-11; // Gravitationskonstante
	private double M = 5.98E24; // Erdmasse
	private double R = 6.37E6; // Erdradius
	// pro Zeiteinheit ausgestossene Gasmasse
	// mit konstanter Geschwindigkeit v_ab
	private double alpha = 13.84E3; 
	private double m0 = 1E6; // Masse Raketenkopf
	double mt1; // Treibstoffmasse
	double m1; // Tankh"ullenmasse
	private double v_ab;// Ausstossgeschwindigkeit relativ zur Rakete

	// Treibstoffmasse von aussen einlesen
	public void setMt1(double mt1) {
		this.mt1 = mt1;
	}
	
	//Tankh"ullenmasse von aussen einlesen
	public void setM1(double m1){
		this.m1=m1;
	}

	// Ausstossgeschwindigkeit von aussen einlesen
	public void setV_ab(double v_ab) {
		this.v_ab = v_ab;
	}

	/**
	 * @param n = Dimension
	 * @param h = Schrittweite
	 * @param t0 = Anfangszeitpunkt
	 * @param t1 = Endzeitpunkt
	 * @param x0 = Vektor mit Anfangszeit, 
	 *             Anfangsh"ohe und Anfangsgeschwindigkeit
	 */
	RaketeDgl1(int n, double h, double t0, double t1, double[] x0) {
		super(n, h, t0, t1, x0);
	}

	// Methode zur Bestimmung der Abwurfh"ohe
	public double getAbwurf(double t) {
		double ret;
		if (alpha * t <= mt1) {
			ret = 0;
		} else {
			ret = 1;
		}
		return ret;
	}

	// Methode zur Bestimmung der Beschleunigung
	public double getBeschl(double t, double x) {
		double ret;
		if (alpha * t <= mt1) {
			ret = -G * M * 1 / Math.pow(x + R, 2) + alpha
					/ ((m0 + mt1 + m1) - alpha * t) * v_ab;
		} else {
			ret = -G * M * 1 / Math.pow(x + R, 2);
		}
		return ret;
	}

	// Methode zur Bestimmung der Masse
	public double getMass(double t) {
		double ret;
		if (alpha * t <= mt1) {
			ret = (m0 + mt1 + m1) - alpha * t;
		} else {
			ret = m0;
		}
		return ret;
	}

	// Methode zur Bestimmung der potentiellen Energie
	public double getPot(double x) {
		double ret;
		ret = -G * M * 1 / (x + R);
		//ohne *getMass(t) --> normiert auf die Masse
		return ret;
	}

	// Methode zur Bestimmung der kinetischen Energie
	public double getKin(double v) {
		double ret;
		ret = 0.5 * Math.pow(v, 2);
		//ohne *getMass(t) --> normiert auf die Masse
		return ret;
	}

	// Methode zur Bestimmung der Gesamtenergie
	public double getEnergie(double x, double v) {
		double ret;
		ret = getPot(x) + getKin(v);
		return ret;
	}

	// DGL für RK --> Zeit, H"ohe und Geschwindigkeit
	public double[] fn(double t, double[] x) {
		double[] ret = new double[n];
		if (alpha * x[0] <= mt1) {
			ret[0] = 1.0;
			ret[1] = x[2];
			ret[2] = -G * M * 1 / Math.pow(x[1] + R, 2) + alpha
					/ (m0 + m1 + mt1 - alpha * x[0]) * v_ab;
		} else {
			ret[0] = 1.0;
			ret[1] = x[2];
			ret[2] = -G * M * 1 / Math.pow(x[1] + R, 2);
		}
		return ret;
	}
}

/*
 * This software is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General 
 * Public License (GPL) as published by the Free Software 
 * Foundation; either version 3 of the License, 
 * or(at your option) any later version.
 *
 * This software is distributed in the hope that it will 
 * be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE.  
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General 
 * Public License along with this; 
 * if not, see <http://www.gnu.org.licenses>
 */
