package rakete;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.EventQueue;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.awt.Insets;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.image.BufferedImage;
import java.io.IOException;

import javax.imageio.ImageIO;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JScrollPane;
import javax.swing.JSlider;
import javax.swing.SwingConstants;

import org.opensourcephysics.display.BoundedImage;
import org.opensourcephysics.display.DrawingPanel;
import org.opensourcephysics.display.PlottingPanel;
import org.opensourcephysics.display.axes.CartesianType1;

/**
 * Klasse zum Anlegen der Oberfl"ache, 
 * Objekte der ein- und zweistufigen Rakete,
 * sowie die Tankobjekte werden mit Anfangsbedingungen 
 * belegt und an die Sim-Datei "ubergeben,
 * ruft RaketeSim auf
 * @author Sarah Hipp
 *
 */

public class RaketeHaupt extends JFrame {

	/*
	 * Starte die Anwendung
	 */
	public static void main(String[] args) {
		EventQueue.invokeLater(new Runnable() {
			@Override
			public void run() {
				try {
					RaketeHaupt frame = new RaketeHaupt();
					frame.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	// Fenster gestalten
	public RaketeHaupt() {

		// Einzelne Schriftgr"ossen und Hintergrundfarbe festlegen
		Font titelFont = new Font("Arial Unicode MS", Font.BOLD, 25);
		Font uebFont = new Font("Arial Unicode MS", Font.BOLD, 13);
		Font textFont = new Font("Arial Unicode MS", Font.PLAIN, 12);
		Font text2Font = new Font("Arial Unicode MS", Font.ITALIC, 11);
		Color colorbg = new Color(222, 222, 222);

		// Gr"ossen der Raketenbilder und der Buttons festlegen
		Dimension dimImage = new Dimension(100, 50);
		Dimension dimImage1 = new Dimension(84, 50);
		Dimension dimButton = new Dimension(110, 30);

		// grosses Panel anlegen, das sich an Bildschirmgr"osse anpasst,
		// geschlossen werden kann,
		// mit Titel, GridBagLayout und Scrollbar
		setTitle("Raketenstart");
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		Dimension screen = Toolkit.getDefaultToolkit().getScreenSize();
		setSize(screen);
		JPanel contentPane = new JPanel();
		GridBagLayout gbLayout = new GridBagLayout();
		contentPane.setLayout(gbLayout);
		contentPane.setBackground(colorbg);
		JScrollPane scroll = new JScrollPane(contentPane);
		getContentPane().add(scroll);

		// Label f"ur den Titel anlegen
		JLabel titelLabel = new JLabel("Der Raketenstart");
		titelLabel.setFont(titelFont);

		// Panel fu"r die Plots hinzuf"ugen und mit der H"ohe vorbelegen
		PlottingPanel plot = new PlottingPanel("Zeit in s", "H\u00f6he in m",
				"H\u00f6he der Rakete");
		plot.setYMarginPercentage(10);
		plot.setPreferredMinMax(0, 180, 0, 3.1E4);
		plot.setAntialiasTextOn(true);
		plot.enableInspector(false);
		plot.setFont(textFont);
		plot.setBackground(colorbg);

		// Label f"ur die Auswahl der Plots erstellen
		JLabel labelPlot = new JLabel("Auswahl des Plots");
		labelPlot.setFont(uebFont);

		// Check-Box f"ur die Auswahl der Plots erstellen und zu einer
		// Checkboxgroup zusammenfassen
		ButtonGroup checkboxgroupPlot = new ButtonGroup();
		JRadioButton checkboxHoehe = new JRadioButton("H\u00f6he", true);
		JRadioButton checkboxGeschw = new JRadioButton("Geschwindigkeit", false);
		JRadioButton checkboxBeschl = new JRadioButton("Beschleunigung", false);
		JRadioButton checkboxMasse = new JRadioButton("Masse", false);
		JRadioButton checkboxEnergie = new JRadioButton("Energie", false);
		checkboxHoehe.setFont(textFont);
		checkboxHoehe.setBackground(colorbg);
		checkboxGeschw.setFont(textFont);
		checkboxGeschw.setBackground(colorbg);
		checkboxBeschl.setFont(textFont);
		checkboxBeschl.setBackground(colorbg);
		checkboxMasse.setFont(textFont);
		checkboxMasse.setBackground(colorbg);
		checkboxEnergie.setFont(textFont);
		checkboxEnergie.setBackground(colorbg);
		checkboxgroupPlot.add(checkboxHoehe);
		checkboxgroupPlot.add(checkboxGeschw);
		checkboxgroupPlot.add(checkboxBeschl);
		checkboxgroupPlot.add(checkboxMasse);
		checkboxgroupPlot.add(checkboxEnergie);

		JLabel label = new JLabel(""); // F"uller f"ur Layout
		label.setFont(textFont);

		// Panel f"ur die Auswahl des Plots erstellen und Label und Checkboxen
		// hinzuf"ugen
		JPanel plotPanel = new JPanel();
		plotPanel.setLayout(new GridLayout(3, 2, 10, 0));
		plotPanel.add(checkboxHoehe);
		plotPanel.add(label);
		plotPanel.add(checkboxGeschw);
		plotPanel.add(checkboxMasse);
		plotPanel.add(checkboxBeschl);
		plotPanel.add(checkboxEnergie);
		plotPanel.setBackground(colorbg);

		// Label f"ur die Auswahl des Plot-Bereichs erstellen
		JLabel labelBereich = new JLabel("Auswahl des Bereichs");
		labelBereich.setFont(uebFont);

		// Check-Box f"ur die Auswahl des Plot-Bereichs erstellen und zu einer
		// Checkboxgroup zusammenfassen
		ButtonGroup checkboxgroup = new ButtonGroup();
		JRadioButton checkboxGes = new JRadioButton("gesamte Flugphase", true);
		JRadioButton checkboxStart = new JRadioButton("Anfangsteil der Flugphase", false);
		checkboxGes.setFont(textFont);
		checkboxGes.setBackground(colorbg);
		checkboxStart.setFont(textFont);
		checkboxStart.setBackground(colorbg);
		checkboxgroup.add(checkboxGes);
		checkboxgroup.add(checkboxStart);

		// Panel f"ur die Auswahl des Plots-Bereichs erstellen und Label und
		// Checkboxen hinzuf"ugen
		JPanel bereichPanel = new JPanel();
		bereichPanel.setLayout(new BoxLayout(bereichPanel, BoxLayout.Y_AXIS));
		bereichPanel.add(labelBereich);
		bereichPanel.add(checkboxGes);
		bereichPanel.add(checkboxStart);
		bereichPanel.setBackground(colorbg);

		// Panel f"ur Animation erzeugen
		PlottingPanel animation = new PlottingPanel(null, "H\u00f6he in m", "");
		animation.setPreferredMinMax(-10, 10, -1500, 30000);
		animation.setFont(textFont);
		animation.setOpaque(false);
		animation.setAntialiasTextOn(true);
		animation.enableInspector(false);
		animation.setBackground(colorbg);

		// Achsen des Animations-Panels umwandeln,
		// um die Zahlen auf der x-Achse auszuschalten und zwei Ticks
		// hinzuzuf"ugen
		CartesianType1 axes = (CartesianType1) animation.getAxes();
		axes.addXTick("", -5);
		axes.addXTick("", 5);

		// Label f"ur den Tank der einstufigen Rakete erstellen
		JLabel labelTank1 = new JLabel("Treibstoffmasse 1. Stufe in t:");
		labelTank1.setFont(textFont);

		// Schieberegler f"ur die einstufige Rakete erstellen
		JSlider masse1 = new JSlider(SwingConstants.HORIZONTAL, 50, 300, 200);
		masse1.setMajorTickSpacing(50);
		masse1.setMinorTickSpacing(25);
		masse1.setPaintTicks(true);
		masse1.setPaintLabels(true);
		masse1.setSnapToTicks(true);
		masse1.setBackground(colorbg);

		// DrawingPanel f"ur das Bild der einstufigen Rakete anlegen
		DrawingPanel rakete1 = new DrawingPanel();
		rakete1.setPreferredSize(dimImage1);
		rakete1.setBackground(colorbg);

		// Bild der einstufigen Rakete einf"ugen
		BufferedImage rotDatei = null; // leere Variable

		// leere Variable mit einem Bild f"ullen
		// try-catch, um Fehler beim "Offnen der Datei abzufangen
		try {
			rotDatei = ImageIO.read(getClass().getResource("rotMittel.png"));
		} catch (IOException e) {
			e.printStackTrace();
		}

		// mithilfe der rotDatei-Variable ein BoundedImage-Objekt erzeugen
		BoundedImage roteRakete = new BoundedImage(rotDatei, 0, 0);
		roteRakete.setTheta(3 * Math.PI / 2);
		roteRakete.setWidth(roteRakete.getWidth() * 0.18);
		roteRakete.setHeight(roteRakete.getHeight() * 0.18);

		// Bild der einstufigen Rakete zum DrawingPanel hinzuf"ugen
		rakete1.addDrawable(roteRakete);

		// Label f"ur die einstufige Rakete erstellen
		JLabel rotLabel = new JLabel("einstufige Rakete");
		rotLabel.setFont(uebFont);
		rotLabel.setForeground(Color.RED);

		// Panel f"ur die einstufige Rakete erstellen
		// und Bild und Text der Rakete nebeneinander hinzuf"ugen
		JPanel rakete1Panel = new JPanel();
		rakete1Panel.setLayout(new FlowLayout());
		rakete1Panel.add(rakete1);
		rakete1Panel.add(rotLabel);
		rakete1Panel.setBackground(colorbg);

		// Label f"ur die erste Stufe der zweistufigen Rakete erstellen
		JLabel labelTank2a = new JLabel("Treibstoffmasse 1. Stufe in t:");
		labelTank2a.setFont(textFont);

		// Schieberegler f"ur die erste Stufe der zweistufigen Rakete erstellen
		JSlider masse2a = new JSlider(SwingConstants.HORIZONTAL, 50, 250, 200);
		masse2a.setMajorTickSpacing(50);
		masse2a.setMinorTickSpacing(25);
		masse2a.setPaintTicks(true);
		masse2a.setPaintLabels(true);
		masse2a.setSnapToTicks(true);
		masse2a.setBackground(colorbg);

		// Label f"ur die zweite Stufe der zweistufigen Rakete erstellen
		JLabel labelTank2b = new JLabel("Treibstoffmasse 2. Stufe in t:");
		labelTank2b.setFont(textFont);

		// Schieberegler f"ur die zweite Stufe der zweistufigen Rakete erstellen
		JSlider masse2b = new JSlider(SwingConstants.HORIZONTAL, 50, 250, 200);
		masse2b.setMajorTickSpacing(50);
		masse2b.setMinorTickSpacing(25);
		masse2b.setPaintTicks(true);
		masse2b.setPaintLabels(true);
		masse2b.setSnapToTicks(true);
		masse2b.setBackground(colorbg);

		// DrawingPanel f"ur das Bild der zweistufigen Rakete anlegen
		DrawingPanel rakete2 = new DrawingPanel();
		rakete2.setPreferredSize(dimImage);
		rakete2.setBackground(colorbg);

		// Bild der zweistufigen Rakete einf"ugen
		BufferedImage schwarzDatei = null; // leere Variable

		// leere Variable mit einem Bild f"ullen
		// try-catch, um Fehler beim "Offnen der Datei abzufangen
		try {
			schwarzDatei = ImageIO.read(getClass().getResource(
					"schwarzGross.png"));
		} catch (IOException e) {
			e.printStackTrace();
		}

		// mithilfe der schwarzDatei-Variable ein BoundedImage-Objekt erzeugen
		BoundedImage schwarzRakete = new BoundedImage(schwarzDatei, 0, 0);
		schwarzRakete.setTheta(3 * Math.PI / 2);
		schwarzRakete.setWidth(schwarzRakete.getWidth() * 0.18);
		schwarzRakete.setHeight(schwarzRakete.getHeight() * 0.18);

		// Bild der zweistufigen Rakete zum DrawingPanel hinzuf"ugen
		rakete2.addDrawable(schwarzRakete);

		// Label f"ur die zweistufige Rakete erstellen
		JLabel schwarzLabel = new JLabel("zweistufige Rakete");
		schwarzLabel.setFont(uebFont);
		schwarzLabel.setForeground(Color.darkGray);

		// Panel f"ur die zweistufige Rakete erstellen
		// und Bild und Text der Rakete nebeneinander hinzuf"ugen
		JPanel rakete2Panel = new JPanel();
		rakete2Panel.setLayout(new FlowLayout());
		rakete2Panel.add(rakete2);
		rakete2Panel.add(schwarzLabel);
		rakete2Panel.setBackground(colorbg);

		// Label f"ur die Auswahl der Vektoren hinzuf"ugen
		JLabel labelVek = new JLabel("Auswahl der angezeigten Vektoren");
		labelVek.setFont(uebFont);

		// Check-Box f"ur die Auswahl der Vektoren erstellen und zu einer
		// Checkboxgroup zusammenfassen
		ButtonGroup checkboxgroupVek = new ButtonGroup();
		JRadioButton checkboxOhneVek = new JRadioButton("ohne Vektoren", true);
		JRadioButton checkboxGeschwVek = new JRadioButton(
				"Geschwindigkeitsvektoren", false);
		checkboxGeschwVek.setForeground(new Color(34, 200, 221));
		JRadioButton checkboxBeschlVek = new JRadioButton(
				"Beschleunigungsvektoren", false);
		checkboxBeschlVek.setForeground(new Color(51, 204, 80));
		checkboxOhneVek.setFont(textFont);
		checkboxOhneVek.setBackground(colorbg);
		checkboxGeschwVek.setFont(textFont);
		checkboxGeschwVek.setBackground(colorbg);
		checkboxBeschlVek.setFont(textFont);
		checkboxBeschlVek.setBackground(colorbg);
		checkboxgroupVek.add(checkboxOhneVek);
		checkboxgroupVek.add(checkboxGeschwVek);
		checkboxgroupVek.add(checkboxBeschlVek);

		// Panel f"ur die Auswahl der angezeigten Vektoren erstellen und Label
		// und Checkboxen untereinander hinzuf"ugen
		JPanel vekPanel = new JPanel();
		vekPanel.setLayout(new BoxLayout(vekPanel, BoxLayout.Y_AXIS));
		vekPanel.add(labelVek);
		vekPanel.add(checkboxOhneVek);
		vekPanel.add(checkboxGeschwVek);
		vekPanel.add(checkboxBeschlVek);
		vekPanel.setBackground(colorbg);

		// Start/Reset-Button erstellen
		JButton startButton = new JButton("START");
		startButton.setPreferredSize(dimButton);
		startButton.setFont(uebFont);
		JButton resetButton = new JButton("RESET");
		resetButton.setPreferredSize(dimButton);
		resetButton.setFont(uebFont);

		// Info-Button erstellen
		JButton infoButton = new JButton("Infos");
		infoButton.setPreferredSize(dimButton);
		infoButton.setFont(uebFont);

		// Info-Button anschliessen
		infoButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				ParameterFenster fenster = new ParameterFenster(
						RaketeHaupt.this);
				fenster.setVisible(true);
			}
		});

		// Panel f"ur Start-/ und Reset-Button erstellen
		// und Buttons nebeneinander hinzuf"ugen
		JPanel buttonPanel = new JPanel();
		buttonPanel.setLayout(new FlowLayout());
		buttonPanel.add(startButton);
		buttonPanel.add(resetButton);
		buttonPanel.setBackground(colorbg);

		// Check-Box f"ur die Auswahl des Turbo erstellen
		JCheckBox checkboxTurbo = new JCheckBox("Turbo einschalten");
		checkboxTurbo.setFont(textFont);
		checkboxTurbo.setBackground(colorbg);

		// Label f"ur die Auswahl des Turbo erstellen
		JLabel labelBoost = new JLabel();
		labelBoost
				.setText("<html>Erh\u00f6hung der Aussto\u00DFgeschwindigkeit,<br>"
						+ "<html>um die Fluchtgeschwindigkeit zu erreichen.<br>");
		labelBoost.setFont(text2Font);

		// Panel f"ur die Auswahl des Turbo erstellen und
		// Checkbox und Label untereinander hinzuf"ugen
		JPanel turboPanel = new JPanel();
		turboPanel.setLayout(new BoxLayout(turboPanel, BoxLayout.Y_AXIS));
		turboPanel.add(checkboxTurbo);
		turboPanel.add(labelBoost);
		turboPanel.setBackground(colorbg);

		// Elemente auf der Oberfl"ache anordnen (11x4)
		GridBagConstraints gbTitel = new GridBagConstraints();
		gbTitel.gridx = 0;
		gbTitel.gridy = 0;
		gbTitel.gridwidth = 4;
		gbTitel.gridheight = 1;
		gbTitel.anchor = GridBagConstraints.CENTER;
		gbTitel.insets = new Insets(15, 0, 20, 0);
		gbLayout.setConstraints(titelLabel, gbTitel);
		contentPane.add(titelLabel);

		GridBagConstraints gbPlot = new GridBagConstraints();
		gbPlot.gridx = 0;
		gbPlot.gridy = 1;
		gbPlot.gridwidth = 3;
		gbPlot.gridheight = 1;
		gbPlot.insets = new Insets(0, 15, 5, 15);
		gbPlot.weightx = 100;
		gbPlot.weighty = 100;
		gbPlot.fill = GridBagConstraints.BOTH;
		gbPlot.anchor = GridBagConstraints.CENTER;
		gbLayout.setConstraints(plot, gbPlot);
		contentPane.add(plot);

		GridBagConstraints gbLabelAuswahl = new GridBagConstraints();
		gbLabelAuswahl.gridx = 0;
		gbLabelAuswahl.gridy = 2;
		gbLabelAuswahl.gridwidth = 1;
		gbLabelAuswahl.gridheight = 1;
		gbLabelAuswahl.insets = new Insets(0, 40, 0, 0);
		gbLabelAuswahl.anchor = GridBagConstraints.NORTHWEST;
		gbLayout.setConstraints(labelPlot, gbLabelAuswahl);
		contentPane.add(labelPlot);

		GridBagConstraints gbPlotAuswahl = new GridBagConstraints();
		gbPlotAuswahl.gridx = 0;
		gbPlotAuswahl.gridy = 3;
		gbPlotAuswahl.gridwidth = 1;
		gbPlotAuswahl.gridheight = 3;
		gbPlotAuswahl.insets = new Insets(0, 40, 0, 0);
		gbPlotAuswahl.anchor = GridBagConstraints.NORTHWEST;
		gbLayout.setConstraints(plotPanel, gbPlotAuswahl);
		contentPane.add(plotPanel);

		GridBagConstraints gbBereich = new GridBagConstraints();
		gbBereich.gridx = 0;
		gbBereich.gridy = 6;
		gbBereich.gridwidth = 1;
		gbBereich.gridheight = 3;
		gbBereich.insets = new Insets(-15, 40, 0, 0);
		gbBereich.anchor = GridBagConstraints.NORTHWEST;
		gbLayout.setConstraints(bereichPanel, gbBereich);
		contentPane.add(bereichPanel);

		GridBagConstraints gbBoost = new GridBagConstraints();
		gbBoost.gridx = 0;
		gbBoost.gridy = 9;
		gbBoost.gridwidth = 1;
		gbBoost.gridheight = 2;
		gbBoost.insets = new Insets(-15, 40, 0, 0);
		gbBoost.anchor = GridBagConstraints.WEST;
		gbLayout.setConstraints(turboPanel, gbBoost);
		contentPane.add(turboPanel);

		GridBagConstraints gbBild1 = new GridBagConstraints();
		gbBild1.gridx = 1;
		gbBild1.gridy = 2;
		gbBild1.gridwidth = 1;
		gbBild1.gridheight = 2;
		gbBild1.anchor = GridBagConstraints.CENTER;
		gbLayout.setConstraints(rakete1Panel, gbBild1);
		contentPane.add(rakete1Panel);

		GridBagConstraints gbLabelMasse1 = new GridBagConstraints();
		gbLabelMasse1.gridx = 1;
		gbLabelMasse1.gridy = 4;
		gbLabelMasse1.gridwidth = 1;
		gbLabelMasse1.gridheight = 1;
		gbLabelMasse1.anchor = GridBagConstraints.CENTER;
		gbLayout.setConstraints(labelTank1, gbLabelMasse1);
		contentPane.add(labelTank1);

		GridBagConstraints gbMasse1 = new GridBagConstraints();
		gbMasse1.gridx = 1;
		gbMasse1.gridy = 5;
		gbMasse1.gridwidth = 1;
		gbMasse1.gridheight = 1;
		gbMasse1.anchor = GridBagConstraints.CENTER;
		gbLayout.setConstraints(masse1, gbMasse1);
		contentPane.add(masse1);

		GridBagConstraints gbBild2 = new GridBagConstraints();
		gbBild2.gridx = 2;
		gbBild2.gridy = 2;
		gbBild2.gridwidth = 1;
		gbBild2.gridheight = 2;
		gbBild2.anchor = GridBagConstraints.CENTER;
		gbLayout.setConstraints(rakete2Panel, gbBild2);
		contentPane.add(rakete2Panel);

		GridBagConstraints gbLabelMasse2a = new GridBagConstraints();
		gbLabelMasse2a.gridx = 2;
		gbLabelMasse2a.gridy = 4;
		gbLabelMasse2a.gridwidth = 1;
		gbLabelMasse2a.gridheight = 1;
		gbLabelMasse2a.anchor = GridBagConstraints.CENTER;
		gbLayout.setConstraints(labelTank2a, gbLabelMasse2a);
		contentPane.add(labelTank2a);

		GridBagConstraints gbMasse2a = new GridBagConstraints();
		gbMasse2a.gridx = 2;
		gbMasse2a.gridy = 5;
		gbMasse2a.gridwidth = 1;
		gbMasse2a.gridheight = 1;
		gbMasse2a.anchor = GridBagConstraints.CENTER;
		gbLayout.setConstraints(masse2a, gbMasse2a);
		contentPane.add(masse2a);

		GridBagConstraints gbLabelMasse2b = new GridBagConstraints();
		gbLabelMasse2b.gridx = 2;
		gbLabelMasse2b.gridy = 6;
		gbLabelMasse2b.gridwidth = 1;
		gbLabelMasse2b.gridheight = 1;
		gbLabelMasse2b.anchor = GridBagConstraints.CENTER;
		gbLayout.setConstraints(labelTank2b, gbLabelMasse2b);
		contentPane.add(labelTank2b);

		GridBagConstraints gbMasse2b = new GridBagConstraints();
		gbMasse2b.gridx = 2;
		gbMasse2b.gridy = 7;
		gbMasse2b.gridwidth = 1;
		gbMasse2b.gridheight = 1;
		gbMasse2b.anchor = GridBagConstraints.CENTER;
		gbLayout.setConstraints(masse2b, gbMasse2b);
		contentPane.add(masse2b);

		GridBagConstraints gbButton = new GridBagConstraints();
		gbButton.gridx = 1;
		gbButton.gridy = 10;
		gbButton.gridwidth = 1;
		gbButton.gridheight = 1;
		gbButton.insets = new Insets(0, 0, 0, 15);
		gbButton.anchor = GridBagConstraints.WEST;
		gbLayout.setConstraints(buttonPanel, gbButton);
		contentPane.add(buttonPanel);

		GridBagConstraints gbInfoButton = new GridBagConstraints();
		gbInfoButton.gridx = 2;
		gbInfoButton.gridy = 10;
		gbInfoButton.gridwidth = 1;
		gbInfoButton.gridheight = 1;
		gbInfoButton.insets = new Insets(0, 0, 0, 25);
		gbInfoButton.anchor = GridBagConstraints.EAST;
		gbLayout.setConstraints(infoButton, gbInfoButton);
		contentPane.add(infoButton);

		GridBagConstraints gbVektoren = new GridBagConstraints();
		gbVektoren.gridx = 3;
		gbVektoren.gridy = 9;
		gbVektoren.gridwidth = 1;
		gbVektoren.gridheight = 2;
		gbVektoren.anchor = GridBagConstraints.WEST;
		gbVektoren.insets = new Insets(-20, 45, 15, 0);
		gbLayout.setConstraints(vekPanel, gbVektoren);
		contentPane.add(vekPanel);

		GridBagConstraints gbAnimation = new GridBagConstraints();
		gbAnimation.gridx = 3;
		gbAnimation.gridy = 1;
		gbAnimation.gridwidth = 1;
		gbAnimation.gridheight = 8;
		gbAnimation.weightx = 15;
		gbAnimation.weighty = 100;
		gbAnimation.insets = new Insets(0, 0, 0, 15);
		gbAnimation.anchor = GridBagConstraints.CENTER;
		gbAnimation.fill = GridBagConstraints.BOTH;
		gbLayout.setConstraints(animation, gbAnimation);
		contentPane.add(animation);

		// Objekte belegen, Anfangsmassen und Ausstossgeschwindigkeit setzen
		RaketeDgl raketeDgl = 
				new RaketeDgl(3, 0.01, 0, 100, new double[] { 0, 0, 0 });
		raketeDgl.setMt1(2.0E5);
		raketeDgl.setMt2(2.0E5);
		raketeDgl.setV_ab(2.46E3);
		raketeDgl.setM1(3.2E4);
		raketeDgl.setM2(3.2E4);

		RaketeDgl1 raketeDgl1 = new RaketeDgl1(3, 0.01, 0, 100, new double[] {
				0, 0, 0 });
		raketeDgl1.setMt1(2.0E5);
		raketeDgl1.setV_ab(2.46E3);
		raketeDgl1.setM1(3.2E4);

		RaketeDglAbwurf raketeDglAa = new RaketeDglAbwurf(3, 0.01, 0, 100,
				new double[] { 0, 0, 0 });
		RaketeDglAbwurf raketeDglAb = new RaketeDglAbwurf(3, 0.01, 0, 100,
				new double[] { 0, 0, 0 });
		RaketeDglAbwurf raketeDglA1 = new RaketeDglAbwurf(3, 0.01, 0, 100,
				new double[] { 0, 0, 0 });

		// Sim aufrufen
		new RaketeSim(animation, plot, raketeDgl, raketeDgl1, raketeDglAa,
				raketeDglAb, raketeDglA1, startButton, resetButton, masse1,
				masse2a, masse2b, checkboxGes, checkboxStart, checkboxOhneVek,
				checkboxGeschwVek, checkboxBeschlVek, checkboxHoehe,
				checkboxGeschw, checkboxBeschl, checkboxMasse, checkboxEnergie,
				checkboxTurbo);
	}
}

/*
 * This software is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General 
 * Public License (GPL) as published by the Free Software 
 * Foundation; either version 3 of the License, 
 * or(at your option) any later version.
 *
 * This software is distributed in the hope that it will 
 * be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE.  
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General 
 * Public License along with this; 
 * if not, see <http://www.gnu.org.licenses>
 */
