package rakete;
import java.awt.Color;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;

import javax.imageio.ImageIO;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JRadioButton;
import javax.swing.JSlider;
import javax.swing.ToolTipManager;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import org.opensourcephysics.display.Arrow;
import org.opensourcephysics.display.BoundedImage;
import org.opensourcephysics.display.Circle;
import org.opensourcephysics.display.Dataset;
import org.opensourcephysics.display.PlottingPanel;

/**
 * Klasse zum Anschliessen der angelegten Elemente,
 * Darstellung der nach dem Runge-Kutta-Verfahren 
 * berechneten Daten
 * @author Sarah Hipp
 *
 */

public class RaketeSim implements Runnable {

	ScheduledExecutorService executor;

	// Simulationsrate festlegen
	final int FPS = 25;
	// Verz"ogerung festlegen, sodass ein fl"ussiges Bild entsteht
	long delay = (long) (0.3E6 / FPS);

	// Vektoren anlegen
	double[] v = { 0, 0, 0 }; // zweistufige Rakete
	double[] w = { 0, 0, 0 }; // einstufige Rakete
	double[] za; // erster Tank zweistufige Rakete
	double[] zb; // zweiter Tank zweistufige Rakete
	double[] z1; // Tank einstufige Rakete

	// Panels vordefinieren
	PlottingPanel animation;
	PlottingPanel plot;

	// Objekte der DGL-Klassen anlegen
	RaketeDgl raketeDgl; //zweistufige Rakete
	RaketeDgl1 raketeDgl1; //einstufige Rakete
	RaketeDglAbwurf raketeDglAa; //erste Tankh"ulle zweistufige Rakete
	RaketeDglAbwurf raketeDglAb; //zweite Tankh"ulle zweistufige Rakete
	RaketeDglAbwurf raketeDglA1; //Tank einstufige Rakete

	// Start- und Reset-Button vordefinieren
	JButton startButton;
	JButton resetButton;

	// Schieberegler vordefinieren
	JSlider masse1; //Treibstoffmasse einstufige Rakete
	JSlider masse2a; //Treibstoffmasse erster Tank zweistufige Rakete
	JSlider masse2b; //Treibstoffmasse zweiter Tank zweistufigen Rakete

	// Checkboxes f"ur die Auswahl des Bereichs vordefinieren
	JRadioButton checkboxStart;
	JRadioButton checkboxGes;

	// Checkboxes f"ur die Auswahl der angezeigten Vektoren vordefinieren
	JRadioButton checkboxOhneVek;
	JRadioButton checkboxGeschwVek;
	JRadioButton checkboxBeschlVek;

	// Checkboxes f"ur die Auswahl des angezeigten Plots vordefinieren
	JRadioButton checkboxHoehe;
	JRadioButton checkboxGeschw;
	JRadioButton checkboxBeschl;
	JRadioButton checkboxMasse;
	JRadioButton checkboxEnergie;

	// Checkboxes f"ur die Auswahl des Turbo-Boosts vordefinieren
	JCheckBox checkboxTurbo;

	// Kreise f"ur den Energie-Plot vordefinieren
	Circle circle; //zweistufige Rakete
	Circle circle1; //einstufige Rakete

	// Datasets der Plots vordefinieren
	//zweistufige Rakete
	Dataset hoeheData;
	Dataset geschwData;
	Dataset beschlData;
	Dataset massData;
	//einstufige Rakete
	Dataset hoehe1Data;
	Dataset geschw1Data;
	Dataset beschl1Data;
	Dataset mass1Data;
	Dataset potData;

	// Vektoren vordefinieren
	//zweistufige Rakete
	Arrow arrowGeschw;
	Arrow arrowBeschl;
	//einstufige Rakete
	Arrow arrowGeschw1;
	Arrow arrowBeschl1;

	// Linie f"ur den Energie-Plot vordefinieren
	MeineLinie linie;
	
	// Strich f"ur das AnimationsPanel vordefinieren
	MeinStrich strich;

	// boolean f"ur die Auswahl der Ansicht vordefinieren
	boolean umschaltGesStart = true;

	// boolean f"ur die Auswahl der angezeigten Vektoren vordefinieren
	boolean geschwVek;
	boolean beschlVek;
	boolean vektor = true;

	// boolean f"ur die Auswahl des angezeigten Plots vordefinieren
	boolean hoehe = true;
	boolean geschw;
	boolean beschl;
	boolean masse;
	boolean energie;

	// boolean f"ur die Auswahl des Turbo-Boosts vordefinieren
	boolean boost;

	// booelan f"ur den Start-/Stop-Knopf vordefinieren
	boolean sim = false;

	// Objekte der Klasse BoundedImage anlegen
	//zweistufige Rakete (schwarz)
	private BoundedImage schwarzGross;
	private BoundedImage schwarzMittel;
	private BoundedImage schwarzKlein;
	private BoundedImage schwarzTeila;
	private BoundedImage schwarzTeilb;
	//einstufige Rakete (rot)
	private BoundedImage rotMittel;
	private BoundedImage rotKlein;
	private BoundedImage rotTeil;

	// boolean f"ur die Images vordefinieren
	boolean rMittel = true;
	boolean rKlein = true;
	boolean rTeil = true;
	boolean sGross = true;
	boolean sMittel = true;
	boolean sKlein = true;
	boolean sTeila = true;
	boolean sTeilb = true;

	// String f"ur den Hilfetext anlegen
	String text;

	// double zum Anpassen der Panel-Gr"osse des Animations-Panels
	double max = 30000;
	
	//Konstanten belegen
	double G = 6.67E-11; // Gravitationskonstante
	double M = 5.98E24; // Erdmasse
	double R = 6.37E6; // Erdradius

	// Werte f"ur das Gravitationspotential der Erde vordefinieren
	int xAnzahl = 500; // Anzahl der Werte
	double xmax = 3E4; // maximaler x-Wert
	double ymin = -G * M / R; // minimaler y-Wert
	double ymax = -G * M / (xmax + R); // maximaler y-Wert des Potentials
	double ymax2 = ymax; // maximaler y-Wert
	double maxhoehe1 = 0; // maximale H"ohe der einstufigen Rakete
	double maxhoehe = 0; // maximale H"ohe der zweistufigen Rakete
	double maxEnergie = ymax; // maximale Energie beider Raketen

	/**
	 * Initialisierung und Start der Simulationsschleife
	 */
	public RaketeSim(final PlottingPanel animation, final PlottingPanel plot,
			final RaketeDgl raketeDgl, final RaketeDgl1 raketeDgl1,
			RaketeDglAbwurf raketeDglAa, RaketeDglAbwurf raketeDglAb,
			RaketeDglAbwurf raketeDglA1, final JButton startButton,
			JButton resetButton, final JSlider masse1, final JSlider masse2a,
			final JSlider masse2b, final JRadioButton checkboxGes,
			final JRadioButton checkboxStart, final JRadioButton checkboxOhneVek,
			final JRadioButton checkboxGeschwVek, final JRadioButton checkboxBeschlVek,
			JRadioButton checkboxHoehe, JRadioButton checkboxGeschw,
			JRadioButton checkboxBeschl, JRadioButton checkboxMasse,
			JRadioButton checkboxEnergie, final JCheckBox checkboxTurbo) {

		// "Ubergebene Objekte mit den vordefinierten Objekten identifizieren
		this.animation = animation;
		this.plot = plot;
		this.raketeDgl = raketeDgl;
		this.raketeDgl1 = raketeDgl1;
		this.raketeDglAa = raketeDglAa;
		this.raketeDglAb = raketeDglAb;
		this.raketeDglA1 = raketeDglA1;
		this.startButton = startButton;
		this.resetButton = resetButton;
		this.masse1 = masse1;
		this.masse2a = masse2a;
		this.masse2b = masse2b;
		this.checkboxGes = checkboxGes;
		this.checkboxStart = checkboxStart;
		this.checkboxOhneVek = checkboxOhneVek;
		this.checkboxGeschwVek = checkboxGeschwVek;
		this.checkboxBeschlVek = checkboxBeschlVek;
		this.checkboxHoehe = checkboxHoehe;
		this.checkboxGeschw = checkboxGeschw;
		this.checkboxBeschl = checkboxBeschl;
		this.checkboxMasse = checkboxMasse;
		this.checkboxEnergie = checkboxEnergie;
		this.checkboxTurbo = checkboxTurbo;

		// vordefinierte Datasets der Plots anlegen
		//zweistufige Rakete
		hoeheData = new Dataset();
		hoeheData.setMarkerShape(Dataset.NO_MARKER);
		hoeheData.setConnected(true);
		hoeheData.setMaximumPoints(35000);

		geschwData = new Dataset();
		geschwData.setMarkerShape(Dataset.NO_MARKER);
		geschwData.setConnected(true);
		geschwData.setMaximumPoints(35000);

		beschlData = new Dataset();
		beschlData.setMarkerShape(Dataset.NO_MARKER);
		beschlData.setConnected(true);
		beschlData.setMaximumPoints(35000);

		massData = new Dataset();
		massData.setMarkerShape(Dataset.NO_MARKER);
		massData.setConnected(true);
		massData.setMaximumPoints(35000);
		
		//einstufige Rakete
		hoehe1Data = new Dataset();
		hoehe1Data.setMarkerShape(Dataset.NO_MARKER);
		hoehe1Data.setConnected(true);
		hoehe1Data.setLineColor(Color.red);

		geschw1Data = new Dataset();
		geschw1Data.setMarkerShape(Dataset.NO_MARKER);
		geschw1Data.setConnected(true);
		geschw1Data.setLineColor(Color.red);
		
		beschl1Data = new Dataset();
		beschl1Data.setMarkerShape(Dataset.NO_MARKER);
		beschl1Data.setConnected(true);
		beschl1Data.setLineColor(Color.red);

		mass1Data = new Dataset();
		mass1Data.setMarkerShape(Dataset.NO_MARKER);
		mass1Data.setConnected(true);
		mass1Data.setLineColor(Color.red);

		//Gravitationspotential der Erde
		potData = new Dataset();
		potData.setMarkerShape(Dataset.NO_MARKER);
		potData.setConnected(true);
		potData.setLineColor(Color.blue);
		berPotData();

		// Checkbox f"ur die Auswahl des Plots anschliessen
		checkboxHoehe.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				if (e.getStateChange() == ItemEvent.SELECTED) {
					hoehe = true;
					geschw = false;
					beschl = false;
					masse = false;
					energie = false;
					repaintPlot();
				}
			}
		});
		checkboxGeschw.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				if (e.getStateChange() == ItemEvent.SELECTED) {
					hoehe = false;
					geschw = true;
					beschl = false;
					masse = false;
					energie = false;
					repaintPlot();
				}
			}
		});
		checkboxBeschl.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				if (e.getStateChange() == ItemEvent.SELECTED) {
					hoehe = false;
					geschw = false;
					beschl = true;
					masse = false;
					energie = false;
					repaintPlot();
				}
			}
		});
		checkboxMasse.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				if (e.getStateChange() == ItemEvent.SELECTED) {
					hoehe = false;
					geschw = false;
					beschl = false;
					masse = true;
					energie = false;
					repaintPlot();
				}
			}
		});

		checkboxEnergie.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				if (e.getStateChange() == ItemEvent.SELECTED) {
					hoehe = false;
					geschw = false;
					beschl = false;
					masse = false;
					energie = true;
					repaintPlot();
				}
			}
		});

		// Checkbox f"ur die Auswahl der Vektoren anschliessen
		checkboxOhneVek.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				if (e.getStateChange() == ItemEvent.SELECTED) {
					geschwVek = false;
					beschlVek = false;
					arrowGeschw.setX(-15);
					arrowGeschw1.setX(15);
					arrowBeschl.setX(-15);
					arrowBeschl1.setX(15);
				}
			}
		});
		checkboxGeschwVek.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				if (e.getStateChange() == ItemEvent.SELECTED) {
					geschwVek = true;
					beschlVek = false;
					arrowBeschl.setX(-15);
					arrowBeschl1.setX(15);
					arrowGeschw.setX(-5);
					arrowGeschw1.setX(5);
					arrowGeschw.setY(v[1]);
					arrowGeschw1.setY(w[1]);
					arrowGeschw.setYlength(v[2] * 10);
					arrowGeschw1.setYlength(w[2] * 10);
				}
			}
		});
		checkboxBeschlVek.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				if (e.getStateChange() == ItemEvent.SELECTED) {
					geschwVek = false;
					beschlVek = true;
					arrowGeschw.setX(-15);
					arrowGeschw1.setX(15);
					arrowBeschl.setX(-5);
					arrowBeschl1.setX(5);
					arrowBeschl.setY(v[1]);
					arrowBeschl1.setY(w[1]);
					arrowBeschl.setYlength(raketeDgl.getBeschl(v[0], v[1]) * 100);
					arrowBeschl1.setYlength(raketeDgl1.getBeschl(w[0], w[1]) * 100);
				}
			}
		});

		// Checkbox f"ur die Auswahl des Plot-Bereichs anschliessen
		checkboxGes.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				if (e.getStateChange() == ItemEvent.SELECTED) {
					umschaltGesStart = true;
					repaintPlot();
				}
			}
		});
		checkboxStart.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				if (e.getStateChange() == ItemEvent.SELECTED) {
					umschaltGesStart = false;
					repaintPlot();
				}
			}
		});

		// Checkbox f"ur die Auswahl des Turbo anschliessen
		checkboxTurbo.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				if (e.getStateChange() == ItemEvent.SELECTED) {
					boost = true;
					raketeDgl1.setV_ab(3.1E4);
					raketeDgl.setV_ab(3.1E4);
					// ohne repaintPlot, damit w"ahrend run nicht umgestellt werden kann
					// Auswahl des Bereichs wird gesperrt
					checkboxGes.setEnabled(false); 
					checkboxStart.setEnabled(false); 
					// Auswahl der Vektoren wird gesperrt
					checkboxOhneVek.setSelected(true);
					geschwVek = false;
					beschlVek = false;
					checkboxOhneVek.setEnabled(false);
					checkboxBeschlVek.setEnabled(false);
					checkboxGeschwVek.setEnabled(false);
				} else if (e.getStateChange() == ItemEvent.DESELECTED) {
					boost = false;
					raketeDgl1.setV_ab(2.46E3);
					raketeDgl.setV_ab(2.46E3);
					// Auswahl des Bereichs frei geben
					checkboxGes.setEnabled(true);
					checkboxStart.setEnabled(true);
					// Auswahl der Vektoren frei geben
					checkboxOhneVek.setEnabled(true);
					checkboxBeschlVek.setEnabled(true);
					checkboxGeschwVek.setEnabled(true);
				}
			}
		});

		// Schieberegler der beiden Treibstoffmassen anschliessen
		masse1.addChangeListener(new ChangeListener() {
			public void stateChanged(ChangeEvent event) {
				JSlider source;
				source = (JSlider) event.getSource();
				if (!source.getValueIsAdjusting()) {
					raketeDgl1.setMt1(source.getValue() * 1000);
					raketeDgl1.setM1(source.getValue() * 160);
				}
			}
		});
		masse2a.addChangeListener(new ChangeListener() {
			public void stateChanged(ChangeEvent event) {
				JSlider source;
				source = (JSlider) event.getSource();
				if (!source.getValueIsAdjusting()) {
					raketeDgl.setMt1(source.getValue() * 1000);
					raketeDgl.setM1(source.getValue() * 160);
				}
			}
		});
		masse2b.addChangeListener(new ChangeListener() {
			public void stateChanged(ChangeEvent event) {
				JSlider source;
				source = (JSlider) event.getSource();
				if (!source.getValueIsAdjusting()) {
					raketeDgl.setMt2(source.getValue() * 1000);
					raketeDgl.setM2(source.getValue() * 160);
				}
			}
		});

		// Start-/Stop-Button anschliessen
		startButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				if (!sim) {
					// executor starten
					executor = Executors.newScheduledThreadPool(1);
					executor.scheduleAtFixedRate(RaketeSim.this, delay, delay,
							TimeUnit.MICROSECONDS);
					repaintPlot();
					// boolean umstellen und Buttontext "andern nachdem
					// gedr"uckt wurde
					sim = true;
					RaketeSim.this.startButton.setText("PAUSE");
					checkboxTurbo.setEnabled(false); // Turbo-Auswahl sperren
					masse1.setEnabled(false);
					masse2a.setEnabled(false);
					masse2b.setEnabled(false);
				} else {
					// executor beenden
					executor.shutdown();
					// boolean umstellen und Buttontext "andern nachdem
					// gedr"uckt wurde
					sim = false;
					RaketeSim.this.startButton.setText("WEITER");
				}
			}
		});

		// Reset-Button anschliessen
		resetButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				// executor beenden
				executor.shutdown();
				// beim Start-/Stop-Button Text umstellen und boolean umstellen
				RaketeSim.this.startButton.setText("START");
				startButton.setEnabled(true);
				sim = false;
				// Anfangswerte zur"ucksetzen
				v[0] = 0;
				v[1] = 0;
				v[2] = 0;
				w[0] = 0;
				w[1] = 0;
				w[2] = 0;
				raketeDgl.setT0(0);
				double[] x0 = { 0, 0, 0 };
				raketeDgl.setX0(x0);
				raketeDgl1.setT0(0);
				raketeDgl1.setX0(x0);
				// Plots und Animation leeren
				hoeheData.clear();
				geschwData.clear();
				beschlData.clear();
				massData.clear();
				hoehe1Data.clear();
				geschw1Data.clear();
				beschl1Data.clear();
				mass1Data.clear();
				potData.clear();
				plot.clear();
				animation.clear();
				// boolean zur"ucksetzen
				vektor = true;
				rMittel = true;
				rKlein = true;
				rTeil = true;
				sGross = true;
				sMittel = true;
				sKlein = true;
				sTeila = true;
				sTeilb = true;
				// Werte zur"ucksetzen
				max = 30000;
				xmax = 3E4;
				ymin = -G * M / R;
				ymax = -G* M / (xmax + R);
				ymax2 = ymax;
				maxEnergie = ymax;
				// Linien und Kreise des Energie-Plots zur"ucksetzen
				linie.setY(0);
				linie.setY1(0);
				linie.setXmax(xmax);
				circle.setXY(0, raketeDgl.getEnergie(0, 0) - 1E6);
				circle1.setXY(0, raketeDgl1.getEnergie(0, 0) - 1E6);
				// Linien im AnimationsPlot zur"ucksetzen
				strich.setY(-1E8);
				strich.setY1(-1E8);
				// Gravitationspotential der Erde berechnen
				berPotData();
				repaintPlot();
				// Panel der Animation zur"ucksetzen
				animation.setPreferredMinMax(-10, 10, -1500, 30000);
				//Turbo-Auswahl frei schalten
				masse1.setEnabled(true);
				masse2a.setEnabled(true);
				masse2b.setEnabled(true);
				checkboxTurbo.setEnabled(true);
				if (boost) { // falls Turbo ausgew"ahlt
					//Bereich-Auswahl sperren
					checkboxGes.setEnabled(false);
					checkboxStart.setEnabled(false);
				} else { // falls Turbo nicht ausgew"ahlt
					//Auswahl der Vektoren frei schalten
				checkboxOhneVek.setEnabled(true);
				checkboxGeschwVek.setEnabled(true);
				checkboxBeschlVek.setEnabled(true);
				if (geschwVek){
					arrowGeschw.setX(-5);
					arrowGeschw1.setX(5);
				} else if(beschlVek){
					arrowBeschl.setX(-5);
					arrowBeschl1.setX(5);
				}}}
		});

		/*
		 * Bilder laden
		 */

		// Gesamte zweistufige Rakete laden
		BufferedImage schwarzGrossDatei = null; // leere Variable

		// leere Variable mit einem Bild f"ullen
		// try-catch, um Fehler beim "Offnen der Datei abzufangen
		try {
			schwarzGrossDatei = ImageIO.read(getClass().getResource("schwarzGross.png"));
		} catch (IOException e) {
			e.printStackTrace();
		}

		// mithilfe der schwarzGrossDatei-Variable ein BoundedImage-Objekt erzeugen
		schwarzGross = new BoundedImage(schwarzGrossDatei, -5, 0);
		schwarzGross.setWidth(schwarzGross.getWidth() * 0.16);
		schwarzGross.setHeight(schwarzGross.getHeight() * 0.16);

		// mittlere schwarze Rakete laden
		BufferedImage schwarzMittelDatei = null; // leere Variable

		// leere Variable mit einem Bild f"ullen
		// try-catch, um Fehler beim "Offnen der Datei abzufangen
		try {
			schwarzMittelDatei = ImageIO.read(getClass().getResource("schwarzMittel.png"));
		} catch (IOException e) {
			e.printStackTrace();
		}

		// mithilfe der schwarzMittelDatei-Variable ein BoundedImage-Objekt erzeugen
		schwarzMittel = new BoundedImage(schwarzMittelDatei, -5, 0);
		schwarzMittel.setWidth(schwarzMittel.getWidth() * 0.16);
		schwarzMittel.setHeight(schwarzMittel.getHeight() * 0.16);

		// kleine schwarze Rakete laden
		BufferedImage schwarzKleinDatei = null; // leere Variable

		// leere Variable mit einem Bild f"ullen
		// try-catch, um Fehler beim "Offnen der Datei abzufangen
		try {
			schwarzKleinDatei = ImageIO.read(getClass().getResource("schwarzKlein.png"));
		} catch (IOException e) {
			e.printStackTrace();
		}
		// mithilfe der schwarzKleinDatei-Variable ein BoundedImage-Objekt erzeugen
		schwarzKlein = new BoundedImage(schwarzKleinDatei, -5, 0);
		schwarzKlein.setWidth(schwarzKlein.getWidth() * 0.16);
		schwarzKlein.setHeight(schwarzKlein.getHeight() * 0.16);

		// schwarzen Tank laden
		BufferedImage schwarzTeilDatei = null; // leere Variable

		// leere Variable mit einem Bild f"ullen
		// try-catch, um Fehler beim "Offnen der Datei abzufangen
		try {
			schwarzTeilDatei = ImageIO.read(getClass().getResource("schwarzTeil.png"));
		} catch (IOException e) {
			e.printStackTrace();
		}
		// mithilfe der schwarzTeilDatei-Variable zwei BoundedImage-Objekte erzeugen
		schwarzTeila = new BoundedImage(schwarzTeilDatei, -5, 0);
		schwarzTeila.setWidth(schwarzTeila.getWidth() * 0.16);
		schwarzTeila.setHeight(schwarzTeila.getHeight() * 0.16);

		schwarzTeilb = new BoundedImage(schwarzTeilDatei, -5, 0);
		schwarzTeilb.setWidth(schwarzTeilb.getWidth() * 0.16);
		schwarzTeilb.setHeight(schwarzTeilb.getHeight() * 0.16);

		// Gesamte einstufige Rakete laden
		BufferedImage rotMittelDatei = null; // leere Variable

		// leere Variable mit einem Bild f"ullen
		// try-catch, um Fehler beim "Offnen der Datei abzufangen
		try {
			rotMittelDatei = ImageIO.read(getClass().getResource("rotMittel.png"));
		} catch (IOException e) {
			e.printStackTrace();
		}
		//mithilfe der rotMittelDatei-Variable ein BoundedImage-Objekt erzeugen
		rotMittel = new BoundedImage(rotMittelDatei, 5, 0);
		rotMittel.setWidth(rotMittel.getWidth() * 0.16);
		rotMittel.setHeight(rotMittel.getHeight() * 0.16);

		// kleine rote Rakete laden
		BufferedImage rotKleinDatei = null; // leere Variable

		// leere Variable mit einem Bild fuellen
		// try-catch, um Fehler beim Oeffnen der Datei abzufangen
		try {
			rotKleinDatei = ImageIO.read(getClass().getResource("rotKlein.png"));
		} catch (IOException e) {
			e.printStackTrace();
		}
		//mithilfe der rotKleinDatei-Variable ein BoundedImage-Objekt erzeugen
		rotKlein = new BoundedImage(rotKleinDatei, 5, 0);
		rotKlein.setWidth(rotKlein.getWidth() * 0.16);
		rotKlein.setHeight(rotKlein.getHeight() * 0.16);

		// roten Tank laden
		BufferedImage rotTeilDatei = null; // leere Variable

		// leere Variable mit einem Bild fuellen
		// try-catch, um Fehler beim Oeffnen der Datei abzufangen
		try {
			rotTeilDatei = ImageIO.read(getClass().getResource("rotTeil.png"));
		} catch (IOException e) {
			e.printStackTrace();
		}
		//mithilfe der rotTeilDatei-Variable ein BoundedImage-Objekt erzeugen
		rotTeil = new BoundedImage(rotTeilDatei, 5, 0);
		rotTeil.setWidth(rotTeil.getWidth() * 0.16);
		rotTeil.setHeight(rotTeil.getHeight() * 0.16);

		// Geschwindigkeitsvektoren anlegen
		arrowGeschw = new Arrow(-15, 0, 0, 0);
		arrowGeschw.setColor(new Color(34, 200, 221));

		arrowGeschw1 = new Arrow(15, 0, 0, 0);
		arrowGeschw1.setColor(new Color(34, 200, 221));

		// Beschleunigungsvektoren anlegen
		arrowBeschl = new Arrow(-15, 0, 0, 0);
		arrowBeschl.setColor(new Color(51, 204, 80));

		arrowBeschl1 = new Arrow(15, 0, 0, 0);
		arrowBeschl1.setColor(new Color(51, 204, 80));

		// Linie und Kreise des Energie-Plots anlegen
		linie = new MeineLinie(0, 0, xmax);
		circle = new Circle(0, raketeDgl.getEnergie(0, 0) - 1E6);
		circle.color = Color.black;
		circle1 = new Circle(0, raketeDgl1.getEnergie(0, 0) - 1E6);
		circle1.color = Color.red;
		
		//Linie des AnimationsPanels anlegen
		strich = new MeinStrich(0,0);
		
		
		
		/**
		 * Animationsschleife: neue Situation berechnen und alle Views
		 * entsprechend updaten
		 */

	}

	@Override
	public void run() {
		/*
		 * Modell einen Zeitschritt weiterrechnen ggf. kann man hier mehrere
		 * Zeitschritte rechnen, bevor man neu zeichnet
		 */
		
		//Abbruchbedingung ohne und mit Turbo
		if (!boost) { //Turbo nicht ausgew"ahlt
			//10 Schritte rechnen und dann neu zeichnen
			for (int k = 0; k < 10; k++) { 
				if ((v[1] < 0) && (w[1] < 0)) {
					executor.shutdown();
					sim = true;
					//Sart-Button und Vektoren-Auswahl sperren, wenn Simulation beendet
					startButton.setEnabled(false);
					checkboxOhneVek.setEnabled(false);
					checkboxGeschwVek.setEnabled(false);
					checkboxBeschlVek.setEnabled(false);
				} else {
					berSchritt();
				}
			}
		} else { //Turbo ausgew"ahlt
			 //100 Schritte rechnen und dann neu zeichnen
			for (int k = 0; k < 100; k++) {
				if (((v[1] < 0) && (w[1] < 0))
						|| ((w[1] < 0) && (raketeDgl.getEnergie(v[1], v[2]) > -1.25E7))) {
					executor.shutdown();
					sim = true;
					//Start-Button sperren, wenn Simulation beendet
					//Vektoren-Auswahl ist im Turbo-Modus sowieso gesperrt
					startButton.setEnabled(false);
				} else {
					berSchritt();
				}
			}
		}
		if (vektor) {//Vektoren hinzuf"ugen
			animation.addDrawable(arrowGeschw);
			animation.addDrawable(arrowGeschw1);
			animation.addDrawable(arrowBeschl);
			animation.addDrawable(arrowBeschl1);
			vektor = false;
		}

		// Unterscheidung der einzelnen F"alle (Wann ist welche Rakete h"oher?)
		// --> Abbruchbedingung f"urs Zeichnen im AnimationsPanel

		// beide Raketen unter/auf Null
		if ((v[1] < 0) && (w[1] < 0)) {
			paintRakete(v[0], 0, 0, 0);
			paintRakete1(w[0], 0, 0);
			// x- und y-Wert der Kreise setzen
			circle.setX(0);
			circle1.setX(0);
			paintLinie();
			paintStrich();

			arrowGeschw.setX(-15);
			arrowGeschw1.setX(15);
			arrowBeschl.setX(-15);
			arrowBeschl1.setX(15);
			animation.repaint();

			// einstufige Rakete fliegt, zweistufige Rakete unter/auf Null
		} else if ((v[1] < 0) && (w[1] >= 0)) {
			paintRakete(v[0], 0, 0, 0);
			paintRakete1(w[0], w[1], z1[1]);
			// x- und y-Wert der Kreise setzen
			circle.setX(0);
			circle1.setX(w[1]);
			paintLinie();
			paintStrich();

			// Checkbox f"ur die Auswahl der Vektoren anschliessen
			if (geschwVek) {
				// Position und L"ange des Vektors festlegen
				arrowGeschw1.setY(w[1]);
				arrowGeschw1.setYlength(w[2] * 10);
				arrowGeschw.setX(-15);
			} else {
				// Position und L"ange des Vektors festlegen
				arrowBeschl1.setY(w[1]);
				arrowBeschl1.setYlength(raketeDgl1.getBeschl(w[0], w[1]) * 100);
				arrowBeschl.setX(-15);
			}

			// Checkbox f"ur die Auswahl des Turbo-Boost in der Animation
			// anschliessen
			if (boost) {
				if (w[1] > max - 0.1 * max) {
					// Gr"osse des Panels jeweils verdoppeln, wenn Rakete am
					// oberen Rand
					max = 2 * max;
					animation.setPreferredMinMaxY(-0.05 * max, max);
				}
			}
			animation.repaint();

			// dem Dataset Daten hinzuf"ugen
			hoehe1Data.append(w[0], w[1]);
			geschw1Data.append(w[0], w[2]);
			beschl1Data.append(w[0], raketeDgl1.getBeschl(w[0], w[1]));
			mass1Data.append(w[0], raketeDgl1.getMass(w[0]));
			plot.repaint();

			// einstufige Rakete unter/auf Null, zweistufige Rakete fliegt
		} else if ((v[1] >= 0) && (w[1] < 0)) {
			paintRakete(v[0], v[1], za[1], zb[1]);
			paintRakete1(w[0], 0, 0);
			// x- und y-Wert der Kreise setzen
			circle.setX(v[1]);
			circle1.setX(0);
			paintLinie();
			paintStrich();

			// Checkbox f"ur die Auswahl der Vektoren anschliessen
			if (geschwVek) {
				// Position und L"ange des Vektors festlegen
				arrowGeschw.setY(v[1]);
				arrowGeschw.setYlength(v[2] * 10);
				arrowGeschw1.setX(15);
			} else if (beschlVek) {
				// Position und L"ange des Vektors festlegen
				arrowBeschl.setY(v[1]);
				arrowBeschl.setYlength(raketeDgl.getBeschl(v[0], v[1]) * 100);
				arrowBeschl1.setX(15);
			}
			// Checkbox f"ur die Auswahl des Turbo-Boost in der Animation
			// anschliessen
			if (boost) {
				if (v[1] > max - 0.1 * max) {
					// Gr"osse des Panels jeweils verdoppeln, wenn Rakete am
					// oberen Rand
					max = 2 * max;
					animation.setPreferredMinMaxY(-0.05 * max, max);
				}
			}
			animation.repaint();

			// den Datasets der zweistufigen Rakete Daten hinzuf"ugen
			hoeheData.append(v[0], v[1]);
			geschwData.append(v[0], v[2]);
			beschlData.append(v[0], raketeDgl.getBeschl(v[0], v[1]));
			massData.append(v[0], raketeDgl.getMass(v[0]));
			plot.repaint();

			// beide Raketen fliegen
		} else {
			paintRakete(v[0], v[1], za[1], zb[1]);
			paintRakete1(w[0], w[1], z1[1]);
			// x- und y-Werte der Kreise setzen
			circle.setX(v[1]);
			circle1.setX(w[1]);
			paintLinie();
			paintStrich();

			// Checkbox f"ur die Auswahl der Vektoren anschliessen
			if (geschwVek) {
				// Position und L"ange der Vektoren setzen
				arrowGeschw1.setY(w[1]);
				arrowGeschw1.setYlength(w[2] * 10);
				arrowGeschw.setY(v[1]);
				arrowGeschw.setYlength(v[2] * 10);
			} else if (beschlVek) {
				// Position und L"ange der Vektoren setzen
				arrowBeschl1.setY(w[1]);
				arrowBeschl1.setYlength(raketeDgl1.getBeschl(w[0], w[1]) * 100);
				arrowBeschl.setY(v[1]);
				arrowBeschl.setYlength(raketeDgl.getBeschl(v[0], v[1]) * 100);

			}

			// Checkbox f"ur die Auswahl des Turbo-Boost in der Animation
			// anschliessen, dabei die beiden F"alle unterscheiden:
			// zweistufige Rakete h"oher als einstufige und umgekehrt
			if (boost) {
				if (Math.max(v[1], w[1]) > max - 0.1 * max) {
					max = 2 * max;
					animation.setPreferredMinMaxY(-0.05 * max, max);
				}
			}
			animation.repaint();

			// den Datasets Daten hinzuf"ugen
			hoeheData.append(v[0], v[1]);
			geschwData.append(v[0], v[2]);
			beschlData.append(v[0], raketeDgl.getBeschl(v[0], v[1]));
			massData.append(v[0], raketeDgl.getMass(v[0]));

			hoehe1Data.append(w[0], w[1]);
			geschw1Data.append(w[0], w[2]);
			beschl1Data.append(w[0], raketeDgl1.getBeschl(w[0], w[1]));
			mass1Data.append(w[0], raketeDgl1.getMass(w[0]));
			plot.repaint();
		}

		// notwendig, weil unter Linux repaint-Events sonst gepuffert werden
		Toolkit.getDefaultToolkit().sync();
	}
	
	//Methode zum Zeichnen der beiden Linien der Gesamtenergie der Raketen
	//und zum Festlegen der y-Position der beiden Kreise
	private void paintLinie(){
		if (raketeDgl.getEnergie(v[1], v[2]) > circle.getY()) {
			// nur bis beide Tanks abgeworfen wurden,
			// danach ist y-Wert des Kreises und der Linie fest
			// --> Flimmern wird verhindert!
			circle.setY(raketeDgl.getEnergie(v[1], v[2]));
			// y-Wert der Linie der zweistufigen Rakete setzen
			linie.setY(raketeDgl.getEnergie(v[1], v[2]));
		}
		if (raketeDgl1.getEnergie(w[1], w[2]) > circle1.getY()) {
			// nur bis Tank abgeworfen wurde,
			// danach ist y-Wert des Kreises und der Linie fest
			// --> Flimmern wird verhindert!
			circle1.setY(raketeDgl1.getEnergie(w[1], w[2]));
			// y-Wert der Linie der einstufigen Rakete setzen
			linie.setY1(raketeDgl1.getEnergie(w[1], w[2]));
		}
	}
	
	//Methode zum Zeichnen von zwei kleinen waagrechten Linie 
	//im Animationsplot, welche die maximal erreichte H"ohe 
	//der Raketen kennzeichnen, wenn diese wieder sinken.
	private void paintStrich(){
		if (v[1] > strich.getY()){
			strich.setY(v[1]);
		}
		if (w[1] > strich.getY1()){
			strich.setY1(w[1]);
		}
	}

	//Methode rechnet einen Zeitschritt weiter
	//und passt Energie-Werte samt Fenster an
	private void berSchritt() {
		if (v[1] >= 0) {
			v = raketeDgl.schritt(); // zweistufige Rakete
		}
		if (w[1] >= 0) {
			w = raketeDgl1.schritt(); // einstufige Rakete
		}
		za = raketeDglAa.schritt(); // erster Tank zweistufige Rakete
		zb = raketeDglAb.schritt(); // zweiter Tank zweistufige Rakete
		z1 = raketeDglA1.schritt(); // Tank einstufige Rakete

		// Schleife f"ur den Energie-Plot
		maxEnergie = Math.max(raketeDgl.getEnergie(v[1], v[2]),
				raketeDgl1.getEnergie(w[1], w[2]));
		maxhoehe1 = -G* M
				/ raketeDgl1.getEnergie(w[1], w[2]) - R;
		maxhoehe = -G * M / raketeDgl.getEnergie(v[1], v[2])- R;
		
		// Anpassen der Gr"osse des Plotting-Panels
		if (Math.min(Math.max(maxhoehe1, maxhoehe), 2E7) > xmax) {
			double x = 0;
			double f = 0;
			// Zeichnen des Graviationspotentials
			for (int i = 1; i <= xAnzahl; i++) {
				x = xmax + i * xmax / xAnzahl;
				f = -G * M / (x + R);
				potData.append(x, f);
			}
			xmax = 2 * xmax;
			ymax = -G * M / (xmax + R);
			linie.setXmax(xmax); // x-Wert des Endpunktes der Linien setzen
			if (energie) {
				plot.setPreferredMinMaxX(0, xmax);
				ymax2 = Math.max(ymax, maxEnergie + .1*Math.abs(ymin-maxEnergie));
				plot.setPreferredMinMaxY(ymin,ymax2);
			}
		}
		if ((maxEnergie + .1*Math.abs(ymin-maxEnergie)) > ymax2){
			if (energie) {
				ymax2 = Math.max(ymax, maxEnergie + .1*Math.abs(ymin-maxEnergie));
				plot.setPreferredMinMaxY(ymin,ymax2);
			}
		}
	}

	// Methode zum Zeichnen der Simulation der einstufigen Rakete,
	// gibt an, wann welches Bild gezeichnet werden soll
	private void paintRakete1(double t, double hoehe, double hoeheTeil) {
		if (raketeDgl1.getAbwurf(t) == 0) { // vor Abwurfhoehe
			// mittlere rote Rakete einmal zeichnen, danach nur noch verschieben
			// --> weniger Aufwand
			if (rMittel) {
				// damit Vektoren "uber der Rakete gezeichnet werden
				animation.addDrawableAtIndex(1, rotMittel);
				// Position des Bildes festlegen
				rotMittel.setXY(5, hoehe);
				rMittel = false;
			} else {
				rotMittel.setXY(5, hoehe);
			}
		} else if (raketeDgl1.getAbwurf(t) == 1) {// nach Abwurfh"ohe
			// kleine rote Rakete einmal zeichnen, danach nur noch verschieben
			if (rKlein) {
				// mittlere rote Rakete entfernen
				animation.removeDrawable(rotMittel);
				// damit Vektoren "uber der Rakete gezeichnet werden
				animation.addDrawableAtIndex(1, rotKlein);
				// Position des Bildes festlegen
				rotKlein.setXY(5, hoehe);
				rKlein = false;
			} else {
				rotKlein.setXY(5, hoehe);
			}
			// Bewegung des roten Tanks abw"arts, verschoben um die halbe
			// Bildgroesse der Rakete
			// und die halbe Bildgr"osse des Tanks nach unten
			if (rTeil) {
				// Anfangswerte setzen f"ur DGL des Tanks
				double[] anfang = { w[0], w[1], w[2] - 200 }; 
				raketeDglA1.setX0(anfang);
				z1 = raketeDglA1.schritt();
			}
			if (z1[1] > animation.pixToY((int) (animation.yToPix(0) - 0.5
					* rotKlein.getHeight() - 0.5 * rotTeil.getHeight()))) {
				// roten Tank einmal zeichnen, danach nur noch verschieben
				if (rTeil) {
					animation.addDrawable(rotTeil);
					rotTeil.setXY(
							5,
							animation.pixToY((int) (animation.yToPix(z1[1])
									+ 0.5 * rotKlein.getHeight() + 0.5 * rotTeil
									.getHeight())));
					rTeil = false;
				} else {
					rotTeil.setXY(
							5,
							animation.pixToY((int) (animation.yToPix(hoeheTeil)
									+ 0.5 * rotKlein.getHeight() + 0.5 * rotTeil
									.getHeight())));
				}

			} else {
				// roten Tank entfernen
				animation.removeDrawable(rotTeil);
			}
		}
	}

	// Methode zum Zeichnen der Simulation der zweistufigen Rakete,
	// gibt an, wann welches Bild gezeichnet werden soll
	private void paintRakete(double t, double hoehe, double hoeheTeil1,
			double hoeheTeil2) {
		if (raketeDgl.getAbwurf(t) == 0) {// vor erster Abwurfh"ohe
			// grosse schwarze Rakete einmal zeichnen, 
			//danach nur noch verschieben
			if (sGross) {
				// damit Vektoren "uber der Rakete gezeichnet werden
				animation.addDrawableAtIndex(1, schwarzGross); 
				schwarzGross.setXY(-5, hoehe);
				sGross = true;
			} else {
				schwarzGross.setXY(-5, hoehe);
			}
		} else if (raketeDgl.getAbwurf(t) == 1) {// nach erster Abwurfh"ohe
			// mittlere schwarze Rakete einmal zeichnen, 
			//danach nur noch verschieben
			if (sMittel) {
				// grosse schwarze Rakete entfernen
				animation.removeDrawable(schwarzGross);
				// damit Vektoren "uber der Rakete gezeichnet werden
				animation.addDrawableAtIndex(1, schwarzMittel);
				schwarzMittel.setXY(-5, hoehe);
				sMittel = false;
			} else {
				schwarzMittel.setXY(-5, hoehe);
			}
			if (sTeila) {
				//Anfangswerte setzen f"ur die DGL des ersten Tanks
				double[] anfang = { v[0], v[1], v[2] - 200 };
				raketeDglAa.setX0(anfang);
				za = raketeDglAa.schritt();
			}
			// Bewegung des ersten schwarzen Tanks abw"arts, verschoben um die
			// halbe Bildgr"osse der Rakete
			// und die halbe Bildgr"osse des Tanks nach unten
			if (za[1] > animation
					.pixToY((int) (animation.yToPix(0) - 0.5
							* schwarzKlein.getHeight() - 0.5 * schwarzTeila
							.getHeight()))) {
				// schwarzen Tank einmal zeichnen, danach nur noch verschieben
				if (sTeila) {
					animation.addDrawable(schwarzTeila);
					schwarzTeila
							.setXY(-5,
									animation.pixToY((int) (animation
											.yToPix(za[1])
											+ 0.5
											* schwarzKlein.getHeight() + 0.5 * schwarzTeila
											.getHeight())));
					sTeila = false;
				} else {
					schwarzTeila.setXY(-5, animation.pixToY((int) (animation
							.yToPix(hoeheTeil1)
							+ 0.5
							* schwarzKlein.getHeight() + 0.5 * schwarzTeila
							.getHeight())));
				}
			} else {
				animation.removeDrawable(schwarzTeila);
			}
		} else if (raketeDgl.getAbwurf(t) == 2) {// nach zweiter Abwurfh"ohe
			// kleine schwarze Rakete einmal zeichnen, danach nur noch
			// verschieben
			if (sKlein) {
				// mittlere schwarze Rakete entfernen
				animation.removeDrawable(schwarzMittel);
				animation.addDrawableAtIndex(1, schwarzKlein);
				schwarzKlein.setXY(-5, hoehe);
				sKlein = false;
			} else {
				schwarzKlein.setXY(-5, hoehe);
			}
			// Bewegung des ersten und zweiten schwarzen Tanks abw"arts,
			// verschoben um die halbe Bildgr"osse der Rakete und die halbe
			// Bildgr"osse des Tanks nach unten.
			if (za[1] > animation
					.pixToY((int) (animation.yToPix(0) - 0.5
							* schwarzKlein.getHeight() - 0.5 * schwarzTeila
							.getHeight()))) {
				schwarzTeila
						.setXY(-5, animation.pixToY((int) (animation
								.yToPix(hoeheTeil1)
								+ 0.5
								* schwarzKlein.getHeight() + 0.5 * schwarzTeila
								.getHeight())));
			} else {
				animation.removeDrawable(schwarzTeila);
			}
			if (sTeilb) {
				//Anfangswerte setzen f"ur DGL des zweiten Tanks
				double[] anfang = { v[0], v[1], v[2] - 200 };
				raketeDglAb.setX0(anfang);
				zb = raketeDglAb.schritt();
			}
			if (zb[1] > animation
					.pixToY((int) (animation.yToPix(0) - 0.5
							* schwarzKlein.getHeight() - 0.5 * schwarzTeilb
							.getHeight()))) {
				// schwarzen Tank einmal zeichnen, danach nur noch verschieben
				if (sTeilb) {
					animation.addDrawable(schwarzTeilb);
					schwarzTeilb
							.setXY(-5,
									animation.pixToY((int) (animation
											.yToPix(zb[1])
											+ 0.5
											* schwarzKlein.getHeight() + 0.5 * schwarzTeilb
											.getHeight())));
					sTeilb = false;
				} else {
					schwarzTeilb.setXY(-5, animation.pixToY((int) (animation
							.yToPix(hoeheTeil2)
							+ 0.5
							* schwarzKlein.getHeight() + 0.5 * schwarzTeilb
							.getHeight())));
				}
			} else {
				// schwarzen Tank entfernen
				animation.removeDrawable(schwarzTeilb);
			}
		}
	}

	// Methode zur Auswahl des gezeichneten Plots
	private void repaintPlot() {
		animation.addDrawableAtIndex(0, strich);
		if (hoehe) {
			plot.clear();
			plot.addDrawable(hoehe1Data);
			plot.addDrawable(hoeheData);
			plot.setTitle("H\u00f6he der Rakete");
			plot.setXLabel("Zeit in s");
			plot.setYLabel("H\u00f6he in m");
			if (!boost) {
				plot.setPreferredMinMax(0, berAchsen(umschaltGesStart)[0], 0,
						berAchsen(umschaltGesStart)[1]);
			} else {
				plot.setAutoscaleY(true);
				plot.setAutoscaleX(true);
			}
			plot.repaint();
			// Tooltip
			text = "<html><b>Erkl\u00e4rung zur H\u00f6he der Rakete: </b><br>"
					+ "<html>Mit Abwurf des letzten Tanks endet der Schub.<br>"
					+ "<html>Die Kurve hat hier einen Wendepunkt. Danach<br>"
					+ "<html>wirkt nur noch die Erdanziehungskraft. Die H\u00f6he<br>"
					+ "<html>der Raketen nimmt trotzdem zun\u00e4chst weiter zu.";
			plot.setToolTipText(text);
			// Aktuelle Dauer holen:
			int dismissDelay = ToolTipManager.sharedInstance()
					.getDismissDelay();
			// Tooltip sichtbar halten:
			dismissDelay = Integer.MAX_VALUE;
			ToolTipManager.sharedInstance().setDismissDelay(dismissDelay);
			ToolTipManager.sharedInstance().registerComponent(plot);
		} else if (geschw) {
			plot.clear();
			plot.addDrawable(geschw1Data);
			plot.addDrawable(geschwData);
			plot.setTitle("Geschwindigkeit der Rakete");
			plot.setXLabel("Zeit in s");
			plot.setYLabel("Geschwindigkeit in m/s");
			if (!boost) {
				plot.setPreferredMinMax(0, berAchsen(umschaltGesStart)[0],
						berAchsen(umschaltGesStart)[2],
						berAchsen(umschaltGesStart)[3]);
			} else {
				plot.setAutoscaleY(true);
				plot.setAutoscaleX(true);
			}
			plot.repaint();
			text = "<html><b>Erkl\u00e4rung zur Geschwindigkeit der Rakete: </b><br>"
					+ "<html>Die Geschwindigkeit der Raketen nimmt solange zu,<br>"
					+ "<html>bis der/die Brennstofftanks abgeworfen wurden. <br>"
					+ "<html>Danach nimmt die Geschwindigkeit ab. <br>"
					+ "<html>Wird sie negativ, so f\u00e4llt die Rakete zur\u00fcck "
					+ "auf den Boden.<br>"
					+ "<html>Hat die Rakete die Fluchtgeschwindigkeit erreicht, <br>"
					+ "<html>so n\u00e4hert sich die Geschwindigkeit einem "
					+ "konstanten Wert an.";
			plot.setToolTipText(text);
			// Aktuelle Dauer holen:
			int dismissDelay = ToolTipManager.sharedInstance()
					.getDismissDelay();
			// Tooltip sichtbar halten:
			dismissDelay = Integer.MAX_VALUE;
			ToolTipManager.sharedInstance().setDismissDelay(dismissDelay);
			ToolTipManager.sharedInstance().registerComponent(plot);
		} else if (beschl) {
			plot.clear();
			plot.addDrawable(beschlData);
			plot.addDrawable(beschl1Data);
			plot.setTitle("Beschleunigung der Rakete");
			plot.setXLabel("Zeit in s");
			plot.setYLabel("Beschleunigung in m/s\u00B2");
			if (!boost) {
				plot.setPreferredMinMax(0, berAchsen(umschaltGesStart)[0],
						berAchsen(umschaltGesStart)[4],
						berAchsen(umschaltGesStart)[5]);
			} else {
				plot.setAutoscaleY(true);
				plot.setAutoscaleX(true);
			}
			plot.repaint();
			text = "<html><b>Erkl\u00e4rung zur Beschleunigung der Rakete:</b><br>"
					+ "<html>W\u00e4hrend der Brennphase nimmt die "
					+ "Beschleunigung der Raketen zu.<br> "
					+ "Danach wirkt nur noch die Erdbeschleunigung nach unten.";
			plot.setToolTipText(text);
			// Aktuelle Dauer holen:
			int dismissDelay = ToolTipManager.sharedInstance()
					.getDismissDelay();
			// Tooltip sichtbar halten:
			dismissDelay = Integer.MAX_VALUE;
			ToolTipManager.sharedInstance().setDismissDelay(dismissDelay);
			ToolTipManager.sharedInstance().registerComponent(plot);
		} else if (masse) {
			plot.clear();
			plot.addDrawable(massData);
			plot.addDrawable(mass1Data);
			plot.setTitle("Masse der Rakete");
			plot.setXLabel("Zeit in s");
			plot.setYLabel("Masse in kg");
			if (!boost) {
				plot.setPreferredMinMax(0, berAchsen(umschaltGesStart)[0],
						0.9E6, berAchsen(umschaltGesStart)[6]);
			} else {
				plot.setAutoscaleY(true);
				plot.setAutoscaleX(true);
			}
			plot.repaint();
			text = "<html><b>Erkl\u00e4rung zur Masse der Rakete: </b><br>"
					+ "<html>W\u00e4hrend des Brennens nimmt die Masse "
					+ "der Raketen linear ab.<br> "
					+ "<html>Wird ein leerer Treibstofftank abgeworfen,  <br>"
					+ "<html>verringert sich die Masse schlagartig.<br>"
					+ "<html>Zum Schluss bleibt die konstante Masse des "
					+ "Raketenkopfs \u00fcbrig.<br>";
			plot.setToolTipText(text);
			// Aktuelle Dauer holen:
			int dismissDelay = ToolTipManager.sharedInstance()
					.getDismissDelay();
			// Tooltip sichtbar halten:
			dismissDelay = Integer.MAX_VALUE;
			ToolTipManager.sharedInstance().setDismissDelay(dismissDelay);
			ToolTipManager.sharedInstance().registerComponent(plot);
		} else if (energie) {
			plot.clear();
			plot.addDrawable(potData);
			plot.addDrawable(linie);
			plot.addDrawable(circle);
			plot.addDrawable(circle1);
			plot.setTitle("Energie der Rakete");
			plot.setXLabel("H\u00f6he in m");
			plot.setYLabel("Energie in J/kg");
			plot.setPreferredMinMaxX(0, xmax);
			ymax2 = Math.max(ymax, maxEnergie + .1*Math.abs(ymin-maxEnergie));
			plot.setPreferredMinMaxY(ymin,ymax2);
			plot.repaint();
			text = "<html><b>Erkl\u00e4rung zur Energie der Rakete: </b><br>"
					+ "<html>Dargestellt ist die Bewegung der Raketen im "
					+ "Gravitationspotential der Erde (blau).<br>"
					+ "<html>Die Gesamtenergie nimmt w\u00e4hrend der Brennphase zu "
					+ "und ist nach Abwurf der Tanks konstant. <br>"
					+ "<html>Mit Erreichen der Fluchtgeschwindigkeit reicht "
					+ "die Energie der Rakete aus, <br>"
					+ "<html>um das Erdpotential zu verlassen.";
			plot.setToolTipText(text);
			// Aktuelle Dauer holen:
			int dismissDelay = ToolTipManager.sharedInstance()
					.getDismissDelay();
			// Tooltip sichtbar halten:
			dismissDelay = Integer.MAX_VALUE;
			ToolTipManager.sharedInstance().setDismissDelay(dismissDelay);
			ToolTipManager.sharedInstance().registerComponent(plot);
		}
	}

	// Methode zur Berechnung des Gravitationspotentials
	public void berPotData() {
		double x = 0;
		double f = 0;
		for (int i = 0; i <= xAnzahl; i++) {
			x = i * xmax / xAnzahl;
			f = -G * M / (x + R);
			potData.append(x, f);
		}
	}

	// Methode zum Setzen der Achsen bei der Auswahl des Plotbereichs
	private double[] berAchsen(boolean umschaltGesStart) {
		double[] Achse = { 0, 0, 0, 0, 0, 0, 0 };
		if (umschaltGesStart) { // f"ur gesamte Flugphase
			Achse[0] = 180; // tmax
			Achse[1] = 3.1E4; // hmax
			Achse[2] = -10E2; // vmin
			Achse[3] = 10E2; // vmax
			Achse[4] = -15; // amin
			Achse[5] = 25; // amax
			Achse[6] = 1.6E6; // mmax
		} else { // f"ur ersten Teil der Flugphase
			Achse[0] = 40; // tmax
			Achse[1] = 1.5E4; // hmax
			Achse[2] = -10E2; // vmin
			Achse[3] = 10E2; // vmax
			Achse[4] = -15; // amin
			Achse[5] = 25; // amax
			Achse[6] = 1.6E6; // mmax
		}
		return Achse;
	}
}

/*
 * This software is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General 
 * Public License (GPL) as published by the Free Software 
 * Foundation; either version 3 of the License, 
 * or(at your option) any later version.
 *
 * This software is distributed in the hope that it will 
 * be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE.  
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General 
 * Public License along with this; 
 * if not, see <http://www.gnu.org.licenses>
 */
